(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[     51170,       1216]
NotebookOptionsPosition[     50447,       1181]
NotebookOutlinePosition[     50812,       1197]
CellTagsIndexPosition[     50769,       1194]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Implied volatility expansion for the Heston model", "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.597959818770582*^9, 3.597959888695898*^9}, {
   3.598691843796198*^9, 3.598691878784575*^9}, {3.598692123374341*^9, 
   3.598692149185072*^9}, {3.598695685015595*^9, 3.598695691334046*^9}, 
   3.598697015690859*^9, {3.598697566849069*^9, 3.598697567706442*^9}, {
   3.598982961426049*^9, 3.598982962721182*^9}, {3.5991317618057747`*^9, 
   3.599131764686119*^9}, {3.5995682782076883`*^9, 3.599568284377194*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Disclaimer", "Subtitle",
 FontSize->14]], "Section",
 CellChangeTimes->{
  3.5125543173858905`*^9, {3.5127369729216976`*^9, 3.5127369760808783`*^9}},
 TextAlignment->Center],

Cell["\<\
Date: 25/01/2014

This file was created by: Matthew Lorig, Stefano Pagliarani and Andrea \
Pascucci.

These Mathematica notebooks are provided on an \[OpenCurlyDoubleQuote]as is\
\[CloseCurlyDoubleQuote] basis without warranty of any kind, express or \
implied. Under no circumstances and under no legal theory, whether in tort, \
contract, or otherwise, shall the authors be liable to you or to any other \
person for any indirect, special, incidental, or consequential damages or \
losses. If you do not agree with these terms, then you are advised to not use \
the notebooks.

Please do no redistribute these notebooks.  If you wish to endorse the \
notebooks, then please link to the web-pages of the authors:
http://www.princeton.edu/~mlorig/
http://www.math.unipd.it/~stefanop/
http://www.dm.unibo.it/~pascucci/\
\>", "Text",
 CellChangeTimes->{{3.5127369954359856`*^9, 3.512737125359417*^9}, {
   3.5127371655637164`*^9, 3.5127371663597617`*^9}, {3.512814058730217*^9, 
   3.512814058891226*^9}, 3.526199505602*^9, 3.5268335032155323`*^9, {
   3.5272388928125*^9, 3.527238893671875*^9}, {3.5804506352987995`*^9, 
   3.580450646016018*^9}, 3.5804510585431423`*^9, 3.5804621638150606`*^9, {
   3.5807902968427057`*^9, 3.580790297139106*^9}, {3.590203507604435*^9, 
   3.590203507894435*^9}, {3.599580220348298*^9, 3.599580226144642*^9}}]
}, Open  ]],

Cell["The model:", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}}],

Cell[BoxData[
 RowBox[{"      ", 
  RowBox[{
   StyleBox[
    FormBox[
     RowBox[{
      RowBox[{"d", " ", 
       SubscriptBox["S", "t"]}], "=", 
      RowBox[{
       RowBox[{"r", " ", 
        SubscriptBox["S", "t"], "dt"}], "+", " ", 
       RowBox[{
        SqrtBox[
         SubscriptBox["v", "t"]], " ", 
        SubscriptBox["S", "t"], 
        SubscriptBox["dW", "t"]}]}]}],
     TraditionalForm],
    FontWeight->"Bold"], 
   StyleBox["\[IndentingNewLine]",
    FontWeight->"Bold"], 
   StyleBox["      ",
    FontWeight->"Bold"], 
   StyleBox[
    RowBox[{
     RowBox[{"d", " ", 
      SubscriptBox["v", "t"]}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Kappa]", "(", 
        RowBox[{"\[Theta]", "-", 
         SubscriptBox["v", "t"]}], ")"}], "dt"}], "+", " ", 
      RowBox[{"\[Delta]", " ", 
       SqrtBox[
        SubscriptBox["v", "t"]], 
       SubscriptBox["dB", "t"]}]}]}],
    FontWeight->"Bold"], "\[IndentingNewLine]", 
   StyleBox["\[IndentingNewLine]",
    FontWeight->"Bold"], 
   RowBox[{
    SubscriptBox["v", "0"], "=", 
    RowBox[{"initial", " ", "variance"}]}], "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["S", "0"], "=", 
    RowBox[{"initial", " ", "asset", " ", "value"}]}], "\[IndentingNewLine]", 
   
   RowBox[{"r", "=", 
    RowBox[{"interest", " ", "rate"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"\[Kappa]", "=", 
    RowBox[{"speed", " ", "of", " ", "mean", " ", "reversion"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"\[Theta]", "=", 
    RowBox[{"long", "-", 
     RowBox[{"term", " ", "variance"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"\[Delta]", "=", 
    RowBox[{"vol", " ", "of", " ", "vol"}]}], "\[IndentingNewLine]", 
   RowBox[{"\[Rho]", "=", "correlation"}], "\[IndentingNewLine]", 
   RowBox[{"\[Alpha]", "=", 
    RowBox[{
    "damping", " ", "parameter", " ", "of", " ", "the", " ", "Fourier", " ", 
     "pricing", " ", "method"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"K", "=", " ", "strike"}]}]}]], "DisplayFormula",
 CellChangeTimes->{{3.599204082417858*^9, 3.5992041544418583`*^9}, {
  3.5992041953508577`*^9, 3.599204302770858*^9}, {3.599204367060858*^9, 
  3.599204388841858*^9}, {3.599204441374858*^9, 3.599204454593858*^9}, {
  3.5992199520983505`*^9, 3.5992199520983505`*^9}, {3.599220130965829*^9, 
  3.599220154124208*^9}, {3.5992202886797037`*^9, 3.599220387564768*^9}, {
  3.5992206059106817`*^9, 3.5992207217895226`*^9}, {3.599567763390155*^9, 
  3.599567821014391*^9}, {3.59956790932743*^9, 3.59956797381304*^9}, {
  3.599568004875313*^9, 3.59956803166779*^9}, {3.599571620884863*^9, 
  3.5995717230302887`*^9}, {3.599572570733088*^9, 3.59957259059118*^9}, {
  3.599573191683577*^9, 3.5995732109134398`*^9}, {3.599573240968423*^9, 
  3.599573258175556*^9}, {3.599573394568679*^9, 3.5995734512328587`*^9}, {
  3.599577038731223*^9, 3.599577039306548*^9}, {3.599646710230056*^9, 
  3.599646710535921*^9}},
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->RGBColor[1, 1, 0.85]],

Cell["\<\
Define the n-th order implied vol. expansion \[Sigma]bar[n][T, S0, K, v0, r, \
... ]:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.599571888346801*^9}, {3.59957336260646*^9, 3.599573364659486*^9}, {
   3.599573763220446*^9, 3.599573820048551*^9}, 3.599762999856101*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Get", "[", 
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
    "\"\<coefficients_IV_order4_Heston\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "T", ",", "S0", ",", "v0", ",", "r", ",", "\[Kappa]", ",", "\[Theta]", ",",
     "\[Delta]", ",", "\[Rho]", ",", "\[Alpha]"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"uBS", "[", 
    RowBox[{"T_", ",", "x_", ",", "k_", ",", "\[Sigma]_", ",", "r_"}], "]"}], 
   ":=", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "x"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"Erf", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "k"}], "+", 
            RowBox[{"r", " ", "T"}], "+", "x", "+", 
            FractionBox[
             RowBox[{"T", " ", 
              SuperscriptBox["\[Sigma]", "2"]}], "2"]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["T"], " ", "\[Sigma]"}]], "]"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"k", "-", 
         RowBox[{"r", " ", "T"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Erfc", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "k"}], "+", 
            RowBox[{"r", " ", "T"}], "+", "x", "-", 
            FractionBox[
             RowBox[{"T", " ", 
              SuperscriptBox["\[Sigma]", "2"]}], "2"]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["T"], " ", "\[Sigma]"}]], "]"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\n", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"j", "=", "0"}], ",", 
   RowBox[{"j", "\[LessEqual]", "4"}], ",", 
   RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"uBS\[Sigma]", "[", "j", "]"}], "[", 
      RowBox[{"T_", ",", "x_", ",", "k_", ",", "\[Sigma]_", ",", "r_"}], 
      "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"uBS", "[", 
           RowBox[{"T", ",", "x", ",", "k", ",", "\[Sigma]", ",", "r"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Sigma]", ",", "j"}], "}"}]}], "]"}], "/", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"uBS", "[", 
           RowBox[{"T", ",", "x", ",", "k", ",", "\[Sigma]", ",", "r"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Sigma]", ",", "1"}], "}"}]}], "]"}]}], "//", 
       "Simplify"}], "//", "Evaluate"}]}], " ", ";"}]}], 
  "\[IndentingNewLine]", "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
    RowBox[{"T_", ",", "x_", ",", "k_", ",", "y_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       FractionBox["1", "T"], "2", 
       RowBox[{
        RowBox[{"aI", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "[", 
        RowBox[{"0", ",", "T"}], "]"}]}]], "//", "FullSimplify"}], "//", 
    "Evaluate"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]bar", "[", "0", "]"}], "[", 
    RowBox[{
    "T_", ",", "S0_", ",", "K_", ",", "v0_", ",", "r_", ",", "\[Kappa]_", ",",
      "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
      RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"Log", "[", "S0", "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", "v0"}], ",", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"Log", "[", "K", "]"}]}]}], "}"}]}], "//", "Evaluate"}]}], 
  ";"}], "\n", 
 RowBox[{"For", "[", " ", 
  RowBox[{
   RowBox[{"n", "=", "1"}], ",", 
   RowBox[{"n", "\[LessEqual]", "4"}], ",", 
   RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "n", "]"}], "[", 
      RowBox[{"T_", ",", "x_", ",", "k_", ",", "y_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"T", " ", 
          RowBox[{
           RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
           RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}]}]], 
        RowBox[{"(", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"h", "=", "1"}], "n"], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "0"}], 
            RowBox[{
             RowBox[{
              RowBox[{"dimFIV", "[", 
               RowBox[{"n", ",", "h"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]], 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"FIV", "[", 
               RowBox[{"n", ",", "h"}], "]"}], "[", "T", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"i", "+", "1"}], ",", "1", ",", "1"}], "]"}], "]"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"-", "1"}], 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
                 RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], 
                SqrtBox[
                 RowBox[{"2", " ", "T"}]]}]], ")"}], "i"], 
            RowBox[{"HermiteH", "[", 
             RowBox[{"i", ",", 
              FractionBox[
               RowBox[{"x", "+", 
                RowBox[{"r", " ", "T"}], "-", "k", "-", 
                RowBox[{
                 FractionBox["1", "2"], 
                 SuperscriptBox[
                  RowBox[{
                   RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
                   RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], 
                   "]"}], "2"], "T"}]}], 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
                 RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], 
                SqrtBox[
                 RowBox[{"2", " ", "T"}]]}]]}], "]"}]}]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"n", "!"}]], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"h", "=", "2"}], "n"], 
         RowBox[{
          RowBox[{"BellY", "[", 
           RowBox[{"n", ",", "h", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"mm", "!"}], 
               RowBox[{
                RowBox[{"\[Sigma]", "[", "mm", "]"}], "[", 
                RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], 
                "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"mm", ",", 
                RowBox[{"n", "-", "h", "+", "1"}]}], "}"}]}], "]"}]}], "]"}], 
          
          RowBox[{
           RowBox[{"uBS\[Sigma]", "[", "h", "]"}], "[", 
           RowBox[{"T", ",", "x", ",", "k", ",", 
            RowBox[{
             RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
             RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], 
            ",", "r"}], "]"}]}]}]}]}], "//", "Evaluate"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]bar", "[", "n", "]"}], "[", 
      RowBox[{
      "T_", ",", "S0_", ",", "K_", ",", "v0_", ",", "r_", ",", "\[Kappa]_", 
       ",", "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
         RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], "+", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "1"}], "n"], 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "j", "]"}], "[", 
          RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}]}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", 
          RowBox[{"Log", "[", "S0", "]"}]}], ",", 
         RowBox[{"y", "\[Rule]", "v0"}], ",", 
         RowBox[{"k", "\[Rule]", 
          RowBox[{"Log", "[", "K", "]"}]}]}], "}"}]}], "//", "Evaluate"}]}], 
    ";"}]}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, 3.599572044926639*^9, {
   3.599572597475325*^9, 3.599572606896727*^9}, {3.5995732926543293`*^9, 
   3.599573323590609*^9}, {3.5995736484401913`*^9, 3.599573655595448*^9}, {
   3.599573689680131*^9, 3.599573689998679*^9}, {3.599573723420217*^9, 
   3.5995737548972692`*^9}, {3.599574349145996*^9, 3.599574403392612*^9}, {
   3.59957702493897*^9, 3.599577098077257*^9}, {3.59957988568289*^9, 
   3.599579892355043*^9}, {3.5996442989827747`*^9, 3.599644303150548*^9}, {
   3.599644915637518*^9, 3.5996449332744102`*^9}, {3.5996450003593616`*^9, 
   3.5996450119383593`*^9}, {3.599646828696809*^9, 3.599646849580553*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell["\<\
Define the call option price (via Fourier inversion) and the implied \
volatility (via B&S inversion) for the comparison:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599575770106182*^9, 3.599575770445821*^9}, {
   3.599763010644576*^9, 3.5997630246673594`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "T", ",", "S0", ",", "v0", ",", "r", ",", "\[Kappa]", ",", "\[Theta]", ",",
     "\[Delta]", ",", "\[Rho]", ",", "\[Alpha]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]1", "[", "\[Xi]_", "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], "\[Xi]", 
    RowBox[{"(", 
     RowBox[{"\[Xi]", "+", "\[ImaginaryI]"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Beta]", "[", "\[Xi]_", "]"}], ":=", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "\[Xi]", " ", "\[Rho]", " ", "\[Delta]"}], 
    "-", "\[Kappa]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DD", "[", "\[Xi]_", "]"}], ":=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"\[Beta]", "[", "\[Xi]", "]"}], "2"], "-", 
     RowBox[{"2", " ", 
      RowBox[{"\[Alpha]1", "[", "\[Xi]", "]"}], " ", 
      SuperscriptBox["\[Delta]", "2"]}]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "\[Xi]_", "]"}], ":=", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Beta]", "[", "\[Xi]", "]"}], "+", 
     RowBox[{"DD", "[", "\[Xi]", "]"}]}], 
    SuperscriptBox["\[Delta]", "2"]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "[", "\[Xi]_", "]"}], ":=", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Beta]", "[", "\[Xi]", "]"}], "-", 
     RowBox[{"DD", "[", "\[Xi]", "]"}]}], 
    SuperscriptBox["\[Delta]", "2"]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"g", "[", 
     RowBox[{"\[Xi]_", ",", "\[Omega]_"}], "]"}], ":=", 
    FractionBox[
     RowBox[{
      RowBox[{"a", "[", "\[Xi]", "]"}], "-", "\[Omega]"}], 
     RowBox[{
      RowBox[{"b", "[", "\[Xi]", "]"}], "-", "\[Omega]"}]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Gamma]2", "[", 
    RowBox[{"s_", ",", "t_", ",", "\[Xi]_", ",", "\[Omega]_"}], "]"}], ":=", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"b", "[", "\[Xi]", "]"}], 
      RowBox[{"g", "[", 
       RowBox[{"\[Xi]", ",", "\[Omega]"}], "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"DD", "[", "\[Xi]", "]"}]}], " ", 
        RowBox[{"(", 
         RowBox[{"t", "-", "s"}], ")"}]}]]}], "-", 
     RowBox[{"a", "[", "\[Xi]", "]"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"\[Xi]", ",", "\[Omega]"}], "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"DD", "[", "\[Xi]", "]"}]}], 
        RowBox[{"(", 
         RowBox[{"t", "-", "s"}], ")"}]}]]}], "-", "1"}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Psi]", "[", 
    RowBox[{"T_", ",", "\[Xi]_", ",", "\[Omega]_", ",", "v0_", ",", "r_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "v0"}], "  ", 
     RowBox[{"\[Gamma]2", "[", 
      RowBox[{"0", ",", "T", ",", "\[Xi]", ",", "\[Omega]"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "\[Xi]", " ", "r", " ", "T"}], "-", 
    RowBox[{"\[Kappa]", " ", "\[Theta]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"a", "[", "\[Xi]", "]"}], "T"}], "-", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " "}], 
         SuperscriptBox["\[Delta]", "2"]], 
        RowBox[{"Log", "[", 
         FractionBox[
          RowBox[{
           RowBox[{"g", "[", 
            RowBox[{"\[Xi]", ",", "\[Omega]"}], "]"}], "-", "1"}], 
          RowBox[{
           RowBox[{
            RowBox[{"g", "[", 
             RowBox[{"\[Xi]", ",", "\[Omega]"}], "]"}], 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"DD", "[", "\[Xi]", "]"}]}], "T"}]]}], "-", "1", 
           " "}]], "]"}]}]}], ")"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Charact", "[", 
    RowBox[{"T_", ",", "\[Xi]_", ",", "\[Omega]_", ",", "v0_", ",", "r_"}], 
    "]"}], ":=", 
   RowBox[{"Exp", "[", 
    RowBox[{"\[Psi]", "[", 
     RowBox[{"T", ",", "\[Xi]", ",", "\[Omega]", ",", "v0", ",", "r"}], "]"}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Call", "[", "Heston", "]"}], "[", 
     RowBox[{
     "S0_", ",", "K_", ",", "T_", ",", "r_", ",", "v0_", ",", "\[Kappa]_", 
      ",", "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_", ",", "\[Alpha]_"}], 
     "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "r"}], " ", "T"}]], 
       SuperscriptBox["K", 
        RowBox[{"1", "-", "\[Alpha]"}]], 
       SuperscriptBox["S0", "\[Alpha]"]}], "\[Pi]"], 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{"Re", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Xi]", " ", 
              RowBox[{"Log", "[", 
               FractionBox["S0", "K"], "]"}]}]], 
            RowBox[{"Charact", "[", 
             RowBox[{"T", ",", 
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{"\[Xi]", "+", 
                 RowBox[{"\[ImaginaryI]", " ", "\[Alpha]"}]}], ")"}]}], ",", 
              "0", ",", "v0", ",", "r"}], "]"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "-", "\[Alpha]"}], 
             ")"}], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"\[ImaginaryI]", " ", "\[Xi]"}], "-", "\[Alpha]"}], 
             ")"}]}], ")"}]}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Xi]", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "20"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Implied", " ", "volatility"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImpVol", "[", 
    RowBox[{"CallPrice_", ",", " ", "S0_", ",", "K_", ",", "T_", ",", "r_"}], 
    "]"}], " ", ":=", " ", 
   RowBox[{"FinancialDerivative", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<European\>\"", ",", " ", "\"\<Call\>\""}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<StrikePrice\>\"", " ", "->", " ", "K"}], ",", " ", 
       RowBox[{"\"\<Expiration\>\"", " ", "->", " ", "T"}], ",", " ", 
       RowBox[{"\"\<Value\>\"", " ", "->", " ", "CallPrice"}]}], "}"}], ",", 
     "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<InterestRate\>\"", " ", "->", " ", "r"}], ",", " ", 
       RowBox[{"\"\<CurrentPrice\>\"", " ", "->", " ", "S0"}], ",", " ", 
       RowBox[{"\"\<Dividend\>\"", " ", "->", " ", "0"}]}], "}"}], ",", " ", 
     "\"\<ImpliedVolatility\>\""}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Heston", " ", "Implied", " ", "Vol"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ImpVolHeston", "[", 
   RowBox[{
   "S0_", ",", "K_", ",", "T_", ",", "r_", ",", "v0_", ",", "\[Kappa]_", ",", 
    "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_", ",", "\[Alpha]_"}], "]"}], 
  ":=", 
  RowBox[{"ImpVol", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Call", "[", "Heston", "]"}], "[", 
     RowBox[{
     "S0", ",", "K", ",", "T", ",", "r", ",", "v0", ",", "\[Kappa]", ",", 
      "\[Theta]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Alpha]"}], "]"}], 
    ",", " ", "S0", ",", "K", ",", "T", ",", "r"}], "]"}]}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, {3.5998138750115767`*^9, 3.599813885023179*^9}, {
   3.5998140693231087`*^9, 3.5998142178001013`*^9}, {3.5998142501493073`*^9, 
   3.599814301958192*^9}, {3.599814346501627*^9, 3.599814370293394*^9}, {
   3.5998144086398153`*^9, 3.599814474237537*^9}, {3.5998145608674097`*^9, 
   3.5998146721618233`*^9}, {3.599814704188016*^9, 3.599814704900362*^9}, {
   3.599814752447259*^9, 3.599814758601622*^9}, {3.5998147931491823`*^9, 
   3.599814867407577*^9}, {3.5998149515522537`*^9, 3.5998149757366467`*^9}, {
   3.59981501873916*^9, 3.5998150190144777`*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell["Test:", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599572470029501*^9, 3.599572470582589*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", "Heston"}]}], " ", "parameters", " ", "by", " ", 
    "Bakshi_Cao", "_Chen", " ", 
    RowBox[{
     RowBox[{"1997", "--"}], "--"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Kappa]", "=", "1.15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Theta]", "=", 
     FractionBox["0.04", "1.15"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Delta]", "=", "0.39"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Rho]", "=", 
     RowBox[{"-", "0.64"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"v0", "=", 
     SuperscriptBox["0.2", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S0", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Kmin", "=", 
     RowBox[{"S0", "-", 
      RowBox[{"0.25", " ", 
       SuperscriptBox["T", 
        RowBox[{"1", "/", "2"}]]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Kmax", "=", 
     RowBox[{"S0", "+", 
      RowBox[{"0.25", " ", 
       SuperscriptBox["T", 
        RowBox[{"1", "/", "2"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"--", 
      RowBox[{"--", "Damping"}]}], " ", "parameter", " ", "for", " ", "the", 
     " ", "exact", " ", 
     RowBox[{
      RowBox[{"price", "--"}], "--"}]}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Alpha]", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IVmin", "=", 
     RowBox[{
      RowBox[{"ImpVolHeston", "[", 
       RowBox[{
       "S0", ",", "Kmax", ",", "T", ",", "r", ",", "v0", ",", "\[Kappa]", ",",
         "\[Theta]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Alpha]"}], "]"}],
       "-", "0.01"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Implied Vol: Exact (solid) vs our new code 3rd (Red) vs our new \
code 4th (Green)\>\"", ",", "16", ",", "Blue", ",", "Bold"}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]bar", "[", "3", "]"}], "[", 
        RowBox[{
        "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
         "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"\[Sigma]bar", "[", "4", "]"}], "[", 
        RowBox[{
        "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
         "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], ",", 
       RowBox[{"ImpVolHeston", "[", 
        RowBox[{
        "S0", ",", "K", ",", "T", ",", "r", ",", "v0", ",", "\[Kappa]", ",", 
         "\[Theta]", ",", "\[Delta]", ",", "\[Rho]", ",", "\[Alpha]"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"K", ",", "Kmin", ",", "Kmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", "Green", "}"}], ",", "Black"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Kmin", ",", 
        RowBox[{"IVmin", "-", "0.03"}]}], "}"}]}]}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, 3.5995800475001183`*^9, {3.5995803649031897`*^9, 
   3.599580409592898*^9}, {3.599645075759655*^9, 3.599645161733348*^9}, {
   3.59964690235499*^9, 3.5996469101992292`*^9}, {3.59976518741812*^9, 
   3.599765187926241*^9}, {3.599804467877453*^9, 3.5998044690895224`*^9}, {
   3.5998045564075165`*^9, 3.5998046092455387`*^9}, {3.599815036417884*^9, 
   3.599815051713263*^9}, {3.5998221063320103`*^9, 3.5998221094830103`*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell[BoxData[
 StyleBox["\<\"Implied Vol: Exact (solid) vs our new code 3rd (Red) vs our \
new code 4th (Green)\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{
  3.599580055316103*^9, 3.5996450454932623`*^9, {3.5996450759694033`*^9, 
   3.599645161951758*^9}, {3.599646890700325*^9, 3.59964691042918*^9}, 
   3.599765541957295*^9, 3.599804473167755*^9, {3.5998045716523886`*^9, 
   3.5998046098035707`*^9}, 3.599814922179948*^9, 3.599814984284487*^9, {
   3.599815027016424*^9, 3.5998150525350103`*^9}, 3.5998220904800105`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0Hs0lAkYBvDRRLlt5da6lVFttpZQLLI9Gl3YIoq1aEtCLG2XkTppOS2t
0Jakho5buSQa0kkj2XzjNmbMdOzGYmyixDcMhk9Swn77x3ue8zvP89fLCj6x
P3QRg8E4QN//ueXkeVUGg0RZt8HM1rVSFKp8yNmuQmK97uotnWuk0LvBsU9Y
RMIy5cXCKdpUVdQxNVUSGfOCXcXmUjyaPSTS0iBhf8SLq86SwjrJ9Q9DPRLP
T2aEPjOVYmOulv5mCxLVnLEWiYEU5pLctWFeJBYkOcYVS6Qw2WkurvcmEVm7
5dFa2iufF51YfYCE/KZOW5aaFFoPH9R0+dIuC7r7m6oUH27UeO0JJOHN4BR7
MqWQBP5zwTqMhC1537dtXoKYEe2OT7EkOP5x3Nj3ErRq/Hrp2j0S+zYG8GP7
Jfi4bMBpcobE07dNm/L4Eui+u7qt1k0OtUHPMa9kCchsKsE9Tw7tAWs3gbcE
bON+0+VKOXR6XDghhhL4Xbj8MWv3MJhVrbeHO1vhz+OsSc0Zht/DQ8vLb7Si
r3DoTtXoMDxWPk4ivVphHq8fXLBjBCMZNamJqq2Qr5bEiG+O4HhaT2ZlrRjZ
ac3dP74bgXrX5QgfjhgaA+fjSrcq8MMz1+9kLDHm5vhn7a4oYKGoSgtsF6Hs
U/mjhLcKFLl6iJbFi7BLKN/q6DiKEsmS654bRAgN4BlaJI/CyfxnvSxZC1za
NjjKXo9iG1dClCa0IE/LhtdkPYas4rAVe2xbULNxIjj68hg87UU9BjIhBEbv
w1J6x+C0vEv2IEEIj7aLdd1W43CxtlWGbRYiI7zFX3FpHJutd/cp/m1GkJDr
5tA5jnbmTpdXV5qhFdtRf0ZXifGp3vCv0IwmpvOiym1KZObER8hGmiAYHxxZ
ekwJj3yTc7Z5TTCS/hJTn65EraDIPcqjCRHpX5ZU/KmETh1jMXe+EbM1aolP
3ylh9WQv58yTRgy3/8VYt2ICzkGNtr0RjTDZ37+e5ziBsZ8shubXNGIHX2c6
/MgEtNhe64z6GyDWZoX+fmUCU0FJjNDbDUgXcuKIxxNgm7+KYwc0oPp0gcPB
vgmYnhI6tRk0wOziyhw99Ukk39HbJ+uuR9xZXgnDZhKq30vT1PPr4XTYzNfz
4CRsbKQ+14/Ww6G0s6w6cRI8N+8md8t6ZAxGFiQ+nMSYOCDy9ZQAgxrm7MSe
SVAOWa4zdQLEppuk5jMpOA8tDe1PE+C45lT0qk0UrGSpmj5BAtwdWqb+1I9C
5YtB/lE7AaRlHjuS4mmH91xP0xbA90i4Gb+UwrmGmenRAQJm54XFzJcUXA2t
ZjgCAn7HWJl82ksP21IygsBVn9jkyHYKjm94pmzan602Rb3soPsDOior6gh0
v71lU9BFoexas0plLYF0j7Badi+FHO8kxUc+ASZL9e+LcnqPW9EV5QScvjjc
YDdMwX+VZbAJ7dOz1Y/ltG1czsYn8wj0dURxvRUU3G594x7ygEBtSvtB1jiF
xZGehialBKKnCoaIKQqB+szyjCICZf1zXdHvKRQ73+Mupv3mhZ/YYpqC6Ixx
ZXQhAa/7mry0DxQ67WI5vgUELA9xTgd9oqAf6W5veIdAyB7pUb1ZCtzCvNyU
fALZDut9W2iztNrtP+cR0NDt+dZ6jkJWSO/061wC2xl2Xw/QdnjJX7Wf9rnR
q0aZ8/T/ImNiGnMIVMhIzb0LFErkxvP2tAeF7LkF2gkapVX3swn8Bw10pwA=

     "]]}, 
   {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwV1Xk41GsbB3DZ0iT7XoRKHCdbKfudrZQoWqgcIok4Kmmj7J20ESpSSpFk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     "]]}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV0ns01PkbB/AppahW2wy6kMu2oVq3TOuy9V6S1ildlCX6JazJbkRUWoWE
kEhyabuq6dfNb/jRzaWi7xjDYIRxSm0uhWYwGT5TVmXtZ/94znNe/7zPec77
MQkM9wyeymKxwun8u+0iYqazWHJ0aHzxs+dJcX3K2CXnKXJ4tzbvV/0iBeds
1KrEqXJ0M9vSbgVJQe6H7tGcLoevcbwJO0CK0s+76mdry9HssCCF+ElhnbI2
YwFHDifRiZJ7W6VYfnm27kpzOdw58+PtV0th2nh5CW+LHG4b73Su40jRoB2b
fPqmHA1/RsblVTZhXKfXcfQvOUw2fcXuDWkCuy9zzaOfFBg4kBn/Xr8J8osk
0f2KAtd+9lluX90Il0U9hnNVChjdbNc7vK8R3kdTx/9YPwBPmbXVpG4jdgii
vkm/NAAd9QbjdVUN6L7+7up95QDma4Tpx+5rgGm8biDfdRBzizzz2PoNUBg1
HpLkDiKDN2ZxVSTBxazaDp++QYQsik8ZOyiBdm9M3B2nIdyofEJqjCSYmHgY
zT01hMoUQfgfzfUo/FRUmvh2CDzF7fwZv9fDTaxwcnBQ4qiWrWPEknoE+woW
mKcpsW4aZ9nH9jr8+GyZw8suJTRXmWf5J9Thymwbgcj6PXhdaS6TtnWoWD4S
eCD1Pe62jFlKO8V4uvAD72TnezySDW6bPCWGx7OEqg7LYXAMyzKynMXICanb
MZQ8DK2V0VlvVLXYLc7/yf75MJq2zsXjG7WYfaSdOchWYUflWrmHfy1EGj9M
LVmjgtvmhcNB7Fo8He4fnLlHBc6+YwquVISFTfsOMdkqmL59nu6cLMKv2fNv
FT9WISLRebwfInyu0Ewq71NBs9WFu3+KCAOyFta3X48gPKw/zK+6BgaePWYC
hxFMhudHu5+ogevDeR9DAkawOeJ1wZwtNZDMMQk+cWoEsu50V978GmSLo+Kq
743gU0Xj5cvvhCiL5Nvv7B5BR/Tr7zc9EMI4Qf8SR2sUJj+uU5amCxEXLbjF
shnF+RK7xdxgIRz9jb027RzF443uLd9CCPs7zwvLkkbx0uitJdtIiJz+vfyk
/4/CqChDMo0lRL+2qUvSq1EISZ5iRR+DI9kG6QUaBIt8VRbrmxmEzVIfWGxF
sEFPe6y5gkFnjGtXNXXlkG1dGvWmgRz3IGuCm7ZhtWupreu5i2/ZEBh4vHcv
K2egPhEttrEjqO2aFcovYxAz9fOCdQ4Ef/HV7OMPGKSOT6nau5ZAr1FduLuU
wbV3Olrl3gT3D12qLrjD4G7nF2cfH4Jf93wo5lHXtCtixqi9/M3rVlD3CYVD
XF+CXS/GIstvMzAviH5WupNA9tSsRHaLgcCnK/9/AQQPuIbieTcZlNUXLS3Y
S8CT3GAL+AyaCj1cU+IJlqUdnPC+xOC63hMNu2MEFr3+Vd9QxyRYCrupI7JC
i4YvMljqrePieJzAfqKMnUodN7UFyiSC9W9LxysuMLDasd1p20mCI3ZSM4vz
DM5o+tka5RK87LlQsjSfQcj+hpEG6ldr+X+P5TFY86dTyeE8gnDRiuh66oES
A+vWfAJXjeyBUGqX/3R+l3yewCzQvuN+LgNyN8Bi8AoBGU6XbM5h4BUQYvzw
DoGwZfo1/hl63+sET59CArlSMjOW2sD3QtI4daJoRs7P1G88pXInAUGexxN9
bep9rnYl1cUEksCPrZFZtA8zlovkHoFh/hadDacZVCjzg14/IXA8V+yll8HA
8LeS3LgqgiGH4VXqUwyO9UvERtUEvrHbnVqp13dNLA98SnBeFCzIpJY9C1L3
Cwkak45ytaiVd62SVXUEbV+7NU5LZ2AcI76h0UbgGVYn0U1j4L3H5NxD6nnL
zVLUqQwytx9J2ysjKDYtCmuj/mJpFdrWTqB181PZGeqOt3k2/BcEpbfH3OZS
Z3vwHrl0EuSfbVupm8JAw2R6a4KCIPSNenB1MgPHr/yF3AGC7MfbWkyoIz+X
3VNQ/zBzTtd06u720PytQ/R//usVJU1i8OikbKfJMMFwbFFsAPUBNf9dtZrm
dbDmnE5kUNgz8eLABwJ10Pb9B6nfSL0l5h9p30sWT/hRb7k9S5A1RuCf8Oqk
BfV3u6Iid38iKL8aEVt7nMEvG5qCOJ8JzjbKFxVRX7Q386qjXi0L7sml1ma/
+t56gqDzA7cnmNqZxbXopfZrC120ifqwMnPhub8JvDkRR1dRF7+Uz9o4SbCy
wGaaEXW/2GVikvr33fzSGdT/ALQCnAo=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0.75, 0.1045932026414097},
  Method->{},
  PlotRange->{{0.75, 1.25}, {0.1045932026414097, 0.25145112409001047`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5995800576063957`*^9, 3.599645048380536*^9, {3.599645079006963*^9, 
   3.599645164734126*^9}, {3.59964689357216*^9, 3.599646913279623*^9}, 
   3.599765544438993*^9, 3.5998044775270047`*^9, {3.5998045744715495`*^9, 
   3.5998046125637283`*^9}, 3.599814931618979*^9, 3.5998149934145737`*^9, {
   3.599815029248328*^9, 3.599815054647938*^9}, 3.5998220923220105`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Explicit expressions of the implied vol. expansion:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599572470029501*^9, 3.599572470582589*^9}, {
   3.599579629345312*^9, 3.599579757268725*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "T", ",", "S0", ",", "v0", ",", "r", ",", "\[Kappa]", ",", "\[Theta]", ",", 
   "\[Delta]", ",", "\[Rho]", ",", "\[Alpha]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]bar", "[", "0", "]"}], "[", 
   RowBox[{
   "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
    "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]bar", "[", "1", "]"}], "[", 
   RowBox[{
   "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
    "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, 3.5995800475001183`*^9, 3.599580084720087*^9, {
   3.5998046506199055`*^9, 3.599804663071617*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell[BoxData[
 SqrtBox[
  FractionBox[
   RowBox[{"v0", "-", "\[Theta]", "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "T"}], " ", "\[Kappa]"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "v0"}], "+", "\[Theta]"}], ")"}]}], "+", 
    RowBox[{"T", " ", "\[Theta]", " ", "\[Kappa]"}]}], 
   RowBox[{"T", " ", "\[Kappa]"}]]]], "Output",
 CellChangeTimes->{{3.59957772402394*^9, 3.5995777284103117`*^9}, 
   3.5995799245957747`*^9, {3.599579955759563*^9, 3.599579974414955*^9}, 
   3.59958001084453*^9, 3.599580086885993*^9, 3.599645168463593*^9, 
   3.5996469232848186`*^9, 3.5997655445949697`*^9, 3.5998046637416553`*^9, 
   3.599815057763784*^9}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"v0", "-", "\[Theta]", "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "T"}], " ", "\[Kappa]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "v0"}], "+", "\[Theta]"}], ")"}]}], "+", 
       RowBox[{"T", " ", "\[Theta]", " ", "\[Kappa]"}]}], ")"}], "2"]}], "-", 
   
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "T"}], " ", "\[Kappa]"}]], " ", "\[Delta]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"v0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"T", " ", "\[Kappa]"}]], "-", 
         RowBox[{"T", " ", "\[Kappa]"}]}], ")"}]}], "+", 
      RowBox[{"\[Theta]", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         RowBox[{"T", " ", "\[Kappa]"}], "+", 
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"T", " ", "\[Kappa]"}]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"T", " ", "\[Kappa]"}]}], ")"}]}]}], ")"}]}]}], ")"}], 
    " ", "\[Rho]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", " ", "T"}], "-", 
      FractionBox[
       RowBox[{"v0", "-", "\[Theta]", "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "T"}], " ", "\[Kappa]"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "v0"}], "+", "\[Theta]"}], ")"}]}], "+", 
        RowBox[{"T", " ", "\[Theta]", " ", "\[Kappa]"}]}], 
       RowBox[{"2", " ", "\[Kappa]"}]], "-", 
      RowBox[{"Log", "[", "K", "]"}], "+", 
      RowBox[{"Log", "[", "S0", "]"}]}], ")"}]}]}], 
  RowBox[{"2", " ", 
   SuperscriptBox["T", "2"], " ", 
   SuperscriptBox["\[Kappa]", "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox[
      RowBox[{"v0", "-", "\[Theta]", "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "T"}], " ", "\[Kappa]"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "v0"}], "+", "\[Theta]"}], ")"}]}], "+", 
       RowBox[{"T", " ", "\[Theta]", " ", "\[Kappa]"}]}], 
      RowBox[{"T", " ", "\[Kappa]"}]], ")"}], 
    RowBox[{"3", "/", "2"}]]}]]], "Output",
 CellChangeTimes->{{3.59957772402394*^9, 3.5995777284103117`*^9}, 
   3.5995799245957747`*^9, {3.599579955759563*^9, 3.599579974414955*^9}, 
   3.59958001084453*^9, 3.599580086885993*^9, 3.599645168463593*^9, 
   3.5996469232848186`*^9, 3.5997655445949697`*^9, 3.5998046637416553`*^9, 
   3.599815058368555*^9}]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1440, 852},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1485, 35, 555, 7, 86, "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[2065, 46, 197, 4, 68, "Section"],
Cell[2265, 52, 1352, 26, 220, "Text"]
}, Open  ]],
Cell[3632, 81, 377, 5, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[4012, 88, 3037, 78, 309, "DisplayFormula"],
Cell[7052, 168, 679, 11, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[7734, 181, 10362, 266, 509, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[18099, 449, 698, 11, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[18800, 462, 9688, 248, 569, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[28491, 712, 522, 7, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[CellGroupData[{
Cell[29038, 723, 5312, 122, 444, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[34353, 847, 748, 16, 26, "Print"],
Cell[35104, 865, 8994, 157, 240, "Output"]
}, Open  ]]
}, Open  ]],
Cell[44125, 1026, 626, 10, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[CellGroupData[{
Cell[44776, 1040, 2160, 39, 88, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[46939, 1081, 711, 17, 68, "Output"],
Cell[47653, 1100, 2778, 78, 75, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature CvDGzhhxl0786AKzPytXpiOB *)
