(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[     59970,       1439]
NotebookOptionsPosition[     59287,       1409]
NotebookOutlinePosition[     59630,       1424]
CellTagsIndexPosition[     59587,       1421]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Bond and credit spread expansion for the JDCEV model\
\>", "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.597959818770582*^9, 3.597959888695898*^9}, {
   3.598691843796198*^9, 3.598691878784575*^9}, {3.598692123374341*^9, 
   3.598692149185072*^9}, {3.598695685015595*^9, 3.598695691334046*^9}, 
   3.598697015690859*^9, {3.598697566849069*^9, 3.598697567706442*^9}, {
   3.598982961426049*^9, 3.598982962721182*^9}, {3.5991317618057747`*^9, 
   3.599131764686119*^9}, {3.5995682782076883`*^9, 3.599568284377194*^9}, {
   3.599646720922594*^9, 3.599646721596258*^9}, {3.5997591679337587`*^9, 
   3.5997591854308157`*^9}, {3.599759218513856*^9, 3.5997592207925*^9}, {
   3.599763137327816*^9, 3.599763142424799*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Disclaimer", "Subtitle",
 FontSize->14]], "Section",
 CellChangeTimes->{
  3.5125543173858905`*^9, {3.5127369729216976`*^9, 3.5127369760808783`*^9}},
 TextAlignment->Center],

Cell["\<\
Date: 25/01/2014

This file was created by: Matthew Lorig, Stefano Pagliarani and Andrea \
Pascucci.

These Mathematica notebooks are provided on an \[OpenCurlyDoubleQuote]as is\
\[CloseCurlyDoubleQuote] basis without warranty of any kind, express or \
implied. Under no circumstances and under no legal theory, whether in tort, \
contract, or otherwise, shall the authors be liable to you or to any other \
person for any indirect, special, incidental, or consequential damages or \
losses. If you do not agree with these terms, then you are advised to not use \
the notebooks.

Please do no redistribute these notebooks.  If you wish to endorse the \
notebooks, then please link to the web-pages of the authors:
http://www.princeton.edu/~mlorig/
http://www.math.unipd.it/~stefanop/
http://www.dm.unibo.it/~pascucci/\
\>", "Text",
 CellChangeTimes->{{3.5127369954359856`*^9, 3.512737125359417*^9}, {
   3.5127371655637164`*^9, 3.5127371663597617`*^9}, {3.512814058730217*^9, 
   3.512814058891226*^9}, 3.526199505602*^9, 3.5268335032155323`*^9, {
   3.5272388928125*^9, 3.527238893671875*^9}, {3.5804506352987995`*^9, 
   3.580450646016018*^9}, 3.5804510585431423`*^9, 3.5804621638150606`*^9, {
   3.5807902968427057`*^9, 3.580790297139106*^9}, {3.590203507604435*^9, 
   3.590203507894435*^9}, {3.599580220348298*^9, 3.599580226144642*^9}}],

Cell["The model:", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["      ",
   FontSize->18,
   FontWeight->"Bold"], 
  RowBox[{
   StyleBox[
    RowBox[{
     StyleBox[
      FormBox[
       RowBox[{
        FormBox[
         RowBox[{
          SubscriptBox["S", "t"], "=", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            SubscriptBox["X", "t"]], 
           SubscriptBox["\[CapitalIota]", 
            RowBox[{"{", 
             RowBox[{"\[Zeta]", ">", "t"}], "}"}]]}]}],
         TraditionalForm], ",", " "}],
       TraditionalForm],
      FontSize->18,
      FontWeight->"Bold"], 
     StyleBox["\[IndentingNewLine]",
      FontSize->16,
      FontWeight->"Bold"], 
     StyleBox[
      StyleBox[
       RowBox[{
        StyleBox["     ",
         FontSize->16], 
        StyleBox[" ",
         FontSize->18]}]],
      FontWeight->"Bold"], 
     RowBox[{
      StyleBox[
       FormBox[
        RowBox[{
         FormBox[
          RowBox[{
           RowBox[{"d", " ", 
            SubscriptBox["X", "t"]}], "=", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"r", "+", "b", " ", "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"c", "-", 
                  RowBox[{"1", "/", "2"}]}], ")"}], 
                SuperscriptBox["\[Sigma]", "2"], " ", 
                SuperscriptBox["\[ExponentialE]", 
                 RowBox[{"2", 
                  RowBox[{"(", 
                   RowBox[{"\[Beta]", "-", "1"}], ")"}], 
                  SubscriptBox["X", "t"]}]]}]}], ")"}], "dt"}], "+", " ", 
            RowBox[{"\[Sigma]", " ", 
             SuperscriptBox["\[ExponentialE]", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Beta]", "-", "1"}], ")"}], 
               SubscriptBox["X", "t"]}]], 
             SubscriptBox["dW", "t"]}]}]}],
          TraditionalForm], ",", "        ", 
         RowBox[{"0", "\[LessEqual]", "\[Beta]", "\[LessEqual]", "1"}]}],
        TraditionalForm],
       FontSize->18,
       FontWeight->"Bold"], 
      StyleBox[",",
       FontSize->18,
       FontWeight->"Bold"], 
      StyleBox["  ",
       FontSize->18,
       FontWeight->"Bold"], 
      StyleBox[
       RowBox[{"\[Sigma]", ">", "0"}],
       FontSize->18,
       FontWeight->"Bold"], 
      StyleBox[",",
       FontSize->18,
       FontWeight->"Bold"], 
      StyleBox["\[IndentingNewLine]",
       FontSize->18,
       FontWeight->"Bold"], 
      StyleBox["    ",
       FontSize->18,
       FontWeight->"Bold"], 
      RowBox[{
       StyleBox["\[Zeta]",
        FontSize->18,
        FontWeight->"Bold"], 
       StyleBox[":=",
        FontSize->18,
        FontWeight->"Bold"], 
       RowBox[{
        StyleBox[
         SubscriptBox["inf", 
          RowBox[{"t", ">", "0"}]],
         FontSize->18,
         FontWeight->"Bold"], 
        RowBox[{
         StyleBox["{",
          FontSize->18,
          FontWeight->"Bold"], 
         RowBox[{
          RowBox[{
           StyleBox[
            RowBox[{
             SubsuperscriptBox["\[Integral]", "0", "t"], "b"}],
            FontSize->18,
            FontWeight->"Bold"], 
           StyleBox[" ",
            FontSize->18,
            FontWeight->"Bold"], 
           StyleBox["+",
            FontSize->18,
            FontWeight->"Bold"], 
           RowBox[{
            StyleBox["c",
             FontWeight->"Bold"], 
            StyleBox[" ",
             FontSize->18,
             FontWeight->"Bold"], 
            StyleBox[
             SuperscriptBox["\[Sigma]", "2"],
             FontWeight->"Bold"], 
            StyleBox[" ",
             FontSize->18,
             FontWeight->"Bold"], 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{"2", 
              RowBox[{"(", 
               RowBox[{"\[Beta]", "-", "1"}], ")"}], 
              SubscriptBox["X", "s"]}]], 
            StyleBox[
             RowBox[{"\[DifferentialD]", "s"}],
             FontSize->18,
             FontWeight->"Bold"]}]}], 
          StyleBox["\[GreaterEqual]",
           FontSize->18,
           FontWeight->"Bold"], 
          StyleBox["\[Xi]",
           FontSize->18,
           FontWeight->"Bold"]}], 
         StyleBox["}",
          FontSize->18,
          FontWeight->"Bold"]}]}]}], 
      StyleBox[",",
       FontSize->18,
       FontWeight->"Bold"], 
      StyleBox["       ",
       FontSize->18,
       FontWeight->"Bold"], 
      StyleBox[
       RowBox[{
        StyleBox["\[Xi]",
         FontSize->18], "\[Tilde]", 
        RowBox[{"Exp", 
         RowBox[{"(", "1", ")"}]}]}],
       FontWeight->"Bold"]}]}],
    FontSize->18], "\[IndentingNewLine]", "      ", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["S", "0"], "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      SubscriptBox["X", "0"]], "=", 
     RowBox[{"initial", " ", "asset", " ", "value"}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"r", "=", 
    RowBox[{"interest", " ", "rate"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"\[Sigma]", "=", 
    RowBox[{"constant", " ", "of", " ", "volatility"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"\[Beta]", "=", 
    RowBox[{"elasticity", " ", "of", " ", "volatility"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"b", "=", 
    RowBox[{
    "affine", " ", "parameter", " ", "of", " ", "the", " ", "default", " ", 
     "intensity"}]}], "\[IndentingNewLine]", 
   RowBox[{"c", "=", 
    RowBox[{
    "linear", " ", "parameter", " ", "of", " ", "the", " ", "default", " ", 
     "intensity"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{
     RowBox[{
      RowBox[{"Bond", 
       RowBox[{"(", 
        RowBox[{"T", ",", "S0"}], ")"}]}], "=", 
      RowBox[{"E", "[", " ", 
       RowBox[{"Exp", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           StyleBox[
            RowBox[{
             SubsuperscriptBox["\[Integral]", "0", "T"], "r"}],
            FontSize->18]}], 
          StyleBox["+",
           FontSize->18], 
          StyleBox["b",
           FontSize->18], 
          StyleBox[" ",
           FontSize->18], 
          StyleBox["+",
           FontSize->18], 
          RowBox[{"c", 
           StyleBox[" ",
            FontSize->18], 
           SuperscriptBox["\[Sigma]", "2"], 
           StyleBox[" ",
            FontSize->18], 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"2", 
             RowBox[{"(", 
              RowBox[{"\[Beta]", "-", "1"}], ")"}], 
             SubscriptBox["X", "s"]}]], 
           StyleBox[
            RowBox[{"\[DifferentialD]", "s"}],
            FontSize->18]}]}], ")"}]}], " ", "]"}]}], ";"}],
    FontWeight->"Bold"], 
   StyleBox["\[IndentingNewLine]",
    FontWeight->"Bold"], 
   StyleBox[
    RowBox[{
     StyleBox[
      RowBox[{"CreditSpread", 
       RowBox[{"(", 
        RowBox[{"T", ",", "S0"}], ")"}]}],
      FontWeight->"Bold"], 
     StyleBox["=",
      FontWeight->"Bold"], 
     RowBox[{
      RowBox[{
       StyleBox["-",
        FontWeight->"Bold"], 
       FractionBox[
        RowBox[{"Log", "[", 
         RowBox[{"Bond", 
          RowBox[{"(", 
           RowBox[{"T", ",", "S0"}], ")"}]}], "]"}], "T"]}], "-", "r"}]}],
    FontWeight->"Bold"]}]}]], "DisplayFormula",
 CellChangeTimes->CompressedData["
1:eJxNzFsoQwEAh/EzO5QIrdQKY4ZEacmUKTXjYYvREknmlkttpsZyaWq1vcjU
ypHSLMutlKKUUkpKyJ3lUkaWzJY6a+UyZpy/Jw9fv7eP39qjbI8gCCKFCXKb
Ku/oU59kTaDwQLFY/QLvlq6D0BJ4YPkZjf4pEl6Gc2Ogm7iIhSuZbPv7PznP
qjVoCkrXYfpW4h6kODonVGRs0nBHWhSGWQaNznHmkzzqZwahYmjJDDXkhgVa
I2xWOKJ6HYeH1baaWca0j+YWqNfXHcCA7/wIuu5fuXOMT+LGJKj85qXCbHs5
H9rzlfmQ6u0sgnkdV8F5xpIT75/Ji8P7u4wVJ2VOqL0R0tCyWvgGb93RX7DA
lhOC5mk1K+rcJ0kQlUbCLu1CJuxfjhdB+XZfMSS9dSpINXhaofFnUgOVvKAO
hhddA1DW/mWCAsfEKDR011vhMf1JweQ4OiRjrB0TEnJ8hWQUZFe18eAvJwkI
Fw==
  "],
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->RGBColor[1, 1, 0.85]],

Cell["\<\
Define the n-th order bond price and credit spread expansion, Bondbar[n][T, \
S0, r, ... ] and CSbar[n][T, S0, r, ... ]:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.599571888346801*^9}, {3.59957336260646*^9, 3.599573364659486*^9}, {
   3.599573763220446*^9, 3.599573820048551*^9}, {3.5997599485549707`*^9, 
   3.599759966440024*^9}, {3.599760434603243*^9, 3.599760436856048*^9}, {
   3.599763166719449*^9, 3.599763208206612*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Get", "[", 
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
    "\"\<coefficients_prices_order3_JDCEV\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", ",", 
    "c"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Bondbar", "[", "0", "]"}], "[", 
    RowBox[{
    "T_", ",", "S0_", ",", "r_", ",", "\[Sigma]_", ",", "\[Beta]_", ",", "b_",
      ",", "c_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"aI", "[", 
        RowBox[{"0", ",", "0"}], "]"}], "[", 
       RowBox[{"0", ",", "T"}], "]"}]], "/.", 
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"Log", "[", "S0", "]"}]}], "}"}]}], "//", "Evaluate"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CSbar", "[", "0", "]"}], "[", 
    RowBox[{
    "T_", ",", "S0_", ",", "r_", ",", "\[Sigma]_", ",", "\[Beta]_", ",", "b_",
      ",", "c_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Log", "[", 
        RowBox[{
         RowBox[{"Bondbar", "[", "0", "]"}], "[", 
         RowBox[{
         "T", ",", "S0", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", ",", 
          "c"}], "]"}], "]"}], "T"]}], "-", "r"}], "//", "Evaluate"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", " ", 
  RowBox[{
   RowBox[{"n", "=", "1"}], ",", 
   RowBox[{"n", "\[LessEqual]", "3"}], ",", 
   RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"u", "[", "n", "]"}], "[", 
      RowBox[{"T_", ",", "x_", ",", "k_", ",", "y_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"aI", "[", 
          RowBox[{"0", ",", "0"}], "]"}], "[", 
         RowBox[{"0", ",", "T"}], "]"}]], 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"h", "=", "1"}], "n"], 
        RowBox[{
         RowBox[{
          RowBox[{"F", "[", 
           RowBox[{"n", ",", "h"}], "]"}], "[", "T", "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "]"}], "]"}]}]}], "//",
       "Evaluate"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Bondbar", "[", "n", "]"}], "[", 
      RowBox[{
      "T_", ",", "S0_", ",", "r_", ",", "\[Sigma]_", ",", "\[Beta]_", ",", 
       "b_", ",", "c_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"aI", "[", 
           RowBox[{"0", ",", "0"}], "]"}], "[", 
          RowBox[{"0", ",", "T"}], "]"}]], "+", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "1"}], "n"], 
         RowBox[{
          RowBox[{"u", "[", "j", "]"}], "[", 
          RowBox[{"T", ",", "x", ",", "k", ",", "y"}], "]"}]}]}], "/.", 
       RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
         RowBox[{"Log", "[", "S0", "]"}]}], "}"}]}], "//", "Evaluate"}]}], 
    ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"CSbar", "[", "n", "]"}], "[", 
      RowBox[{
      "T_", ",", "S0_", ",", "r_", ",", "\[Sigma]_", ",", "\[Beta]_", ",", 
       "b_", ",", "c_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"Log", "[", 
          RowBox[{
           RowBox[{"Bondbar", "[", "n", "]"}], "[", 
           RowBox[{
           "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", 
            "b", ",", "c"}], "]"}], "]"}], "T"]}], "-", "r"}], "//", 
      "Evaluate"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, {3.599644286196793*^9, 
   3.599644290338113*^9}, {3.5997593095610123`*^9, 3.599759325094582*^9}, {
   3.599759361360752*^9, 3.599759414408765*^9}, {3.599759766524425*^9, 
   3.5997599271264753`*^9}, {3.599759971488297*^9, 3.599759987993803*^9}, {
   3.5997602445366783`*^9, 3.599760312846043*^9}, {3.5997603740041733`*^9, 
   3.5997604270440903`*^9}, {3.599760969051735*^9, 3.5997609705196133`*^9}, {
   3.599761019731389*^9, 3.599761056593856*^9}, {3.5997611245688477`*^9, 
   3.59976113030586*^9}, {3.5997620335998077`*^9, 3.599762040238823*^9}, {
   3.5997657768217*^9, 3.599765782259137*^9}, {3.5997664290095577`*^9, 
   3.599766429152349*^9}, {3.599773532410859*^9, 3.59977353345767*^9}, {
   3.599806009534487*^9, 3.5998060106488113`*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell["\<\
Define the bond price (truncated series) and the credit spreads formula \
(Mendoza et al 2010) for the comparison:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599575770106182*^9, 3.599575770445821*^9}, {
   3.599760068425452*^9, 3.599760118537854*^9}, {3.599760744287353*^9, 
   3.5997607529178963`*^9}, {3.599763225049925*^9, 3.599763253140602*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{
    "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", ",", 
     "c"}], "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Bond", " ", "prices"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"BondLog", "[", 
    RowBox[{
    "T_", ",", "x_", ",", "\[Sigma]_", ",", "b_", ",", "c_", ",", "\[Beta]_", 
     ",", "r_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Nu]", ",", "A", ",", "\[Omega]", ",", "out"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\[Nu]", "=", 
       FractionBox[
        RowBox[{"1", "+", 
         RowBox[{"2", "c"}]}], 
        RowBox[{"2", 
         RowBox[{"Abs", "[", "\[Beta]", "]"}]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"A", "=", 
       FractionBox[
        RowBox[{"r", "+", "b"}], 
        RowBox[{
         RowBox[{"\[Sigma]", "^", "2"}], " ", 
         RowBox[{"Abs", "[", "\[Beta]", "]"}]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Omega]", "=", 
       RowBox[{"2", 
        RowBox[{"Abs", "[", "\[Beta]", "]"}], 
        RowBox[{"(", 
         RowBox[{"r", "+", "b"}], ")"}]}]}], ";", 
      RowBox[{"out", "=", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"n", "=", "0"}], "70"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"b", " ", "+", " ", 
               RowBox[{"\[Omega]", " ", "n"}]}], ")"}]}], "T"}], "]"}], 
          FractionBox[
           RowBox[{
            RowBox[{"Gamma", "[", 
             RowBox[{"1", "+", 
              RowBox[{"c", "/", 
               RowBox[{"Abs", "[", "\[Beta]", "]"}]}]}], "]"}], 
            RowBox[{"Gamma", "[", 
             RowBox[{"n", "+", 
              RowBox[{"1", "/", 
               RowBox[{"(", 
                RowBox[{"2", 
                 RowBox[{"Abs", "[", "\[Beta]", "]"}]}], ")"}]}]}], "]"}]}], 
           RowBox[{
            RowBox[{"Gamma", "[", 
             RowBox[{"\[Nu]", "+", "1"}], "]"}], 
            RowBox[{"Gamma", "[", 
             RowBox[{"1", "/", 
              RowBox[{"(", 
               RowBox[{"2", 
                RowBox[{"Abs", "[", "\[Beta]", "]"}]}], ")"}]}], "]"}], 
            RowBox[{"n", "!"}]}]], 
          RowBox[{"A", "^", 
           RowBox[{"(", 
            RowBox[{"1", "/", 
             RowBox[{"(", 
              RowBox[{"2", 
               RowBox[{"Abs", "[", "\[Beta]", "]"}]}], ")"}]}], ")"}]}], 
          RowBox[{"Exp", "[", "x", "]"}], 
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", "A"}], " ", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", "2"}], " ", "\[Beta]", " ", "x"}], "]"}]}], "]"}], 
          
          RowBox[{"Hypergeometric1F1", "[", 
           RowBox[{
            RowBox[{"1", "-", "n", "+", 
             RowBox[{"c", "/", 
              RowBox[{"Abs", "[", "\[Beta]", "]"}]}]}], ",", 
            RowBox[{"\[Nu]", "+", "1"}], ",", 
            RowBox[{"A", " ", 
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"-", "2"}], " ", "\[Beta]", " ", "x"}], "]"}]}]}], 
           "]"}]}], ")"}]}]}], ";", "\[IndentingNewLine]", "out"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Bond", "[", 
     RowBox[{
     "T_", ",", "S0_", ",", "r_", ",", "\[Sigma]_", ",", "b_", ",", "c_", ",",
       "\[Beta]_"}], "]"}], ":=", 
    StyleBox[
     RowBox[{"BondLog", "[", 
      RowBox[{"T", ",", 
       RowBox[{"Log", "[", "S0", "]"}], ",", "\[Sigma]", ",", "b", ",", "c", 
       ",", 
       RowBox[{"\[Beta]", "-", "1"}], ",", "r"}], "]"}],
     Background->None]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Credit", " ", "spread"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CS", "[", 
    RowBox[{
    "T_", ",", "S0_", ",", "r_", ",", "\[Sigma]_", ",", "b_", ",", "c_", ",", 
     "\[Beta]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"Log", "[", 
       RowBox[{"Bond", "[", 
        RowBox[{
        "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "b", ",", "c", ",", 
         "\[Beta]"}], "]"}], "]"}], "T"]}], "-", "r"}]}], ";"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, {3.599646401118684*^9, 3.599646450982771*^9}, {
   3.599646522183194*^9, 3.599646556733533*^9}, {3.59964842587702*^9, 
   3.599648434327918*^9}, 3.599648694143137*^9, {3.599648881583283*^9, 
   3.599648885519655*^9}, 3.599760736830225*^9, {3.599760790862464*^9, 
   3.599760840873279*^9}, {3.599760872033848*^9, 3.599761015583226*^9}, {
   3.599761443639882*^9, 3.599761502079899*^9}, {3.599762048961391*^9, 
   3.5997620694751368`*^9}, {3.599766189433692*^9, 3.599766189550276*^9}, {
   3.599766827678743*^9, 3.5997668319317493`*^9}, {3.59977492119757*^9, 
   3.599774979965879*^9}, 3.59977508111598*^9},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell["Test:", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599572470029501*^9, 3.599572470582589*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", "JDCEV"}]}], " ", 
    RowBox[{
     RowBox[{"parameters", "--"}], "--"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "=", "0.3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Beta]", "=", 
     RowBox[{"2", "/", "3"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"c", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S0", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", "0.05"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Tmax", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Tmin", "=", "0.1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Bmin", "=", 
     RowBox[{
      RowBox[{"Bond", "[", 
       RowBox[{
       "Tmax", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "b", ",", "c", ",", 
        "\[Beta]"}], "]"}], "-", "0.01"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Bond price: Exact (solid) vs our new code 2nd (Red) vs our new code \
3rd (Green)\>\"", ",", "16", ",", "Blue", ",", "Bold"}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Bondbar", "[", "2", "]"}], "[", 
        RowBox[{
        "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", 
         ",", "c"}], "]"}], ",", 
       RowBox[{
        RowBox[{"Bondbar", "[", "3", "]"}], "[", 
        RowBox[{
        "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", 
         ",", "c"}], "]"}], ",", 
       RowBox[{"Bond", "[", 
        RowBox[{
        "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "b", ",", "c", ",", 
         "\[Beta]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"T", ",", "Tmin", ",", "Tmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", "Green", "}"}], ",", "Black"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"Bmin", "-", "0.03"}]}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CSmin", "=", 
     RowBox[{
      RowBox[{"CS", "[", 
       RowBox[{
       "Tmax", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "b", ",", "c", ",", 
        "\[Beta]"}], "]"}], "-", "0.01"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Credit spread: Exact (solid) vs our new code 2nd (Red) vs our new \
code 3rd (Green)\>\"", ",", "16", ",", "Blue", ",", "Bold"}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"CSbar", "[", "2", "]"}], "[", 
        RowBox[{
        "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", 
         ",", "c"}], "]"}], ",", 
       RowBox[{
        RowBox[{"CSbar", "[", "3", "]"}], "[", 
        RowBox[{
        "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", 
         ",", "c"}], "]"}], ",", 
       RowBox[{"CS", "[", 
        RowBox[{
        "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "b", ",", "c", ",", 
         "\[Beta]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"T", ",", "Tmin", ",", "Tmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", "Green", "}"}], ",", "Black"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"CSmin", "-", "0.03"}]}], "}"}]}]}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, 3.5995800475001183`*^9, {3.5995803649031897`*^9, 
   3.599580409592898*^9}, {3.599647070705802*^9, 3.59964716438761*^9}, {
   3.599647713315249*^9, 3.599647751728104*^9}, {3.599647871668807*^9, 
   3.59964794464587*^9}, {3.599648856309588*^9, 3.599648856983124*^9}, {
   3.59964890603701*^9, 3.5996489234726152`*^9}, 3.599648997453302*^9, {
   3.599649050969625*^9, 3.5996490650978127`*^9}, {3.599649506419194*^9, 
   3.599649538062111*^9}, 3.599649591436623*^9, {3.599649837639327*^9, 
   3.599649870503463*^9}, 3.5996499048547564`*^9, {3.5996499687491007`*^9, 
   3.5996499710760717`*^9}, {3.59976174414605*^9, 3.599761796865355*^9}, {
   3.599761831008132*^9, 3.5997619226890297`*^9}, {3.599762083585125*^9, 
   3.599762120389104*^9}, {3.599763371990115*^9, 3.599763376237069*^9}, {
   3.599765823120243*^9, 3.5997658474008408`*^9}, {3.599765929586523*^9, 
   3.599765982570468*^9}, 3.5997661233653383`*^9, {3.599766153640605*^9, 
   3.599766153792667*^9}, {3.599766197043974*^9, 3.599766311433443*^9}, {
   3.599766509979024*^9, 3.5997665216551847`*^9}, {3.599766878029728*^9, 
   3.5997669412362757`*^9}, {3.5997671044019957`*^9, 3.599767104801108*^9}, {
   3.599773561027235*^9, 3.599773561937828*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell[BoxData[
 StyleBox["\<\"Bond price: Exact (solid) vs our new code 2nd (Red) vs our new \
code 3rd (Green)\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{
  3.599580055316103*^9, 3.599647676217155*^9, 3.599647722472166*^9, 
   3.599647754841735*^9, {3.599647882766796*^9, 3.599647945533257*^9}, 
   3.599648858179399*^9, 3.5996488901201572`*^9, 3.5996489250088053`*^9, 
   3.5996489978921556`*^9, {3.599649051174417*^9, 3.599649065343054*^9}, {
   3.599649519756646*^9, 3.599649538266728*^9}, 3.5996495916539392`*^9, {
   3.599649837863709*^9, 3.5996498713541527`*^9}, 3.599649906167851*^9, 
   3.599649971306261*^9, 3.599761887325307*^9, 3.599761922966504*^9, {
   3.599762100171895*^9, 3.5997621210652122`*^9}, 3.599762278719192*^9, {
   3.599765798880405*^9, 3.59976585023072*^9}, {3.599765929798993*^9, 
   3.5997659828192663`*^9}, 3.5997661237548313`*^9, 3.599766156715291*^9, {
   3.599766198144003*^9, 3.599766237934782*^9}, 3.599766313078513*^9, 
   3.599766434609971*^9, {3.5997665142402563`*^9, 3.5997665223457747`*^9}, 
   3.599766847831785*^9, {3.599766878259441*^9, 3.599766941894169*^9}, 
   3.599767105481079*^9, {3.599773553366127*^9, 3.5997735624361887`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVx3k41HkcwPHJIokkVAwNvlKWntbOlis+H4yeVB6tjofKmYYupZUjZTGy
jnKWYkNJjmi2oi0kiZZohZ+hxOQcMTLRyG22/eP9vJ63jtdpp6NSNBrN4Xv/
W0wdWriZXgafWC5pN9kiuJGZU5nuUQ7jbjsNZb1EEOUzfDFtQwW4mIhfn3EV
weG5wMXEx89g+ZPNxH6fCBRIiiSypQru7QndJmsjgq1mA+Gl0jUQfMyv9qGW
CK7FaHAytr0G4UuhpJE3BvdSa2yZ7a3QbZf/8/yOMdhx2i5asLEHmr1dmeV6
n2HLNsvq/QECSAstMZnWHYXmkbz2jbdGIdfJIuIUUwgvptb5jBeMg0dYc7id
5QjwrvySkF0vhuV3O0+FHxkGcZOHvrXhNNSF+pRkcz7BCO2fItWwOYgRiiJt
SoYgc/u5w2XXF2HcaWry1KwA7v+pVbVxlobsmrL6cgsBjGTePdodL4XGqlmq
rJRBSFnbIFWkJo1pcWOnuV8HoOpTiPPECxm0VrzQn+I4AI0vm2xzHJdiobxL
elhlPxye4A41SuSweWjQnK3fD84ZhpErCuRRbzr/Ii29D5i7HR6VMRWQI7jv
JtHog9S9sxn8HkV8Wqpp7nOjF1q8d6uf9FfCcc3NUWOkFxoGVQvKklfiDwne
dJeiHvDitTx/zVZG5SV6+z3Ne2DY3lM7YdMqPNMqk2lW9BGYx7a6KcmooKvs
0zSXTj6cVOQLWE0qyJnKFi0w+PDhMzUSnaqKXQk5uSr+3aAQotR46Zgaota/
JdyKLtgUq/XN1Hg1GhWs2TWh3gUrWf4LBcvWIFfoI44/+wEMLFTC1/PX4N7o
ZHoPrxOMn/zhcCB3LYqSON37dnbCfLf1lG2oOgrNP04Pl72Hv2ObhIO2Gmir
plLjYvYe8vwLD12Vo+Nq3mje5It34CzdkC/ppiNOZuX4st7BDL3SinFXE2XS
xnRKeR3gyp98OHdBC+cVtOODjnTAg/VLzlzevg5PTI55Sy+2g1nhwUIDBQb6
MmMfsLLbIapj5jmnj4EZGsWmKZbt4P7qsZL9fm3sNd1TOSPggWuAMpdbrY0H
XNrzRFd4EGitGqdhpIMrPD8u22zBg6W/hsd7JOpgraT6zvx4G8xsUZqTntPB
Pb4xgjd5beDlujSJ466LZ3umDNy920CQk+cl91IXBaMql27rt8GbSt87QiOC
frVZ0XZDFBjQry4rTCIYfzy71ecvCu4VOx1lpxDUtdTfdY5LgZGVcjW5SpBL
cSSR9yn4yTMhOOs6QZpVKj27iIKt+TFDqVkEF3ofMTrzKbBhXnwVVkzwhnSw
w6FbFBzcxY7YV0+wRfOEMDaZgq4uvW7lBoIRJL0uK4kCV79+07eNBG8XMfgl
iRR4JHt8sX9LcKBWtpx/hQJ2x0F3aCdoOP/F0CSOgt+OOFr+OEDQ2O7d54lI
CsRixfShQYJBDrTjy79/YPQbce4QwTi/GoZeBAXnC+2LGUKConqhyYHfKQgX
2dLVJgg6Vp1XrwylQCpCKqj1K8FCtrFnx3kKOKuqWxMnCa7r0esbD6EgeotV
nPwMwQyL1MQNwRTI1c0P1s0SzEn/VmETREGsc4X1pXmCz6p9dNwCKZAfCcm0
WST4StxZFXKOgsuhpjMSCcHSANb1awEU/Afns1+y
     "]]}, 
   {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwVinlYjAkcgDObZyqdytVIk6+IYtHW42p+vxRrpEU52kaHWaVICdWGaHQo
VDptMVjCZEZaD1Jtk6J02LHflybRMR3TpMPoINOk1v7xPu8f72vBDXX3p2lo
aLh953+LGjjfruYUA+dgTAA/QAl/8G+W5fiVQHK0VJ/OVULcgQ/R2YtLIdlS
vzLMWwl71RGTqY//BhvGtM1bdipBl0ifOkuWw9GVxnX0DUpwWNMd80jzOaw6
YB74yEwJWYmmsbnra8F97lpTqvEj3Mt47mwnpeBJa/RMQ/ZH2By6MaHHWgau
zaeG5lkNgv16x4pdx3vA39MvZ5AYgH/77kitbwyAx6Ivve72/fBsbMGBIcEQ
lM/Rdr6LfdCY/FPK9ZpRuK6YnBAHfoBRid8iJ5uv8LU96XjwhV7o06gWmpxW
g1H7W635YgXwN4XvLb48CRcPBYmztRRw/4pZufW4BorX0aqG3Xqgj3/bv/UC
DZtLqk8LBXJIn1tHE87SRBr/zDGevhzKe6M8h59Nxx2ssa4Tod1QXylxvrmN
jilbIwt2d3bB3uECRf2UFmaIUq8+3d4Fnrk2Z/UFOnibxZSW1nSC3Va3h8V2
uri+0TK0aFsnZHiM57bJ9FADXwz6UB1A7t86LzjMALslV4pSuB1QJzcRFKcZ
ogk9LkXwUQbcRlJcG2CEsjSPWxRPBh/Y+5gpy2aiq3CZfiBTBnZBDj4G041x
euTG4YHwdgjWa+txkRgjPUq2/VV5G7wfbOhLyDDBosK8Ar5xG+hGGdTHB83C
fE4hK9y3FZYlmX1ZvXI2alsLm5hlLWDoEvZNoD0HWWpmmp5xCyxZZxxj1TYH
nfZIqrPC3sPKonNuu/Pm4jEeM/58+zuYaHUacz45D80iJeE1G9/BkyRJv9zZ
FGO2nLrGLmmGO2H5nEwtBv4yIz3LwL4ZPDXr7k61MlCR7MGxFbwFFaOMZX57
Pq7V9q4aWvwWvNs+/6U+ZYbn1upOOdxogkKraUcublqA+0RajhzLJliT75W/
RNccXe7x2BH3pRDXpBLHdprjr8KviTY/SsG36rEBexcTnVcdLhCWNoL3caOC
ggomGuXJqRFshAgnk/OmthaYzWHvp+reAH1HzAW/VAuM96KC/vR5Ayp7A7Wm
2gLDq34oPdjfAFxv+qVY34Xo+83wUAWvAXpu3uFqVS7EB8KBQz2MBnhVFnir
35bA2mJV4s8PKFjCyNTOv0TgQ7flRwSuFNwTufsHpBNoYvnOR8mmwJZlVEFk
fv8Pc0McNlOwYl/K79cuE9hbq/HphQsFDncTFRnXCMzchdFdjhRssIuuOi0i
0MN0lXjRCgq8XAN4O2sIHMgu+qfKhIKWFstWozoCrcfPvDE0psA7pGv16/rv
fWRQzTGiwC/N7xP7NYHijEeiYT0KApq8fEFKoM/ZyiwLOgXHftvmuLSbQFpI
bly8ioTRUb0chZzAF8EzsqgxEiISXo3mKQgM/KRTbf6FhBP5bJF5P4ErrAqT
SoZJiFE6M2YNE3hmTcjloX4SaDxaJDVC4FFcLoI+EmJnVlCpnwl86n60I7mX
hAR71nkdFYGH03j3l8pJ0Ho5IX85TmA3bnGJ6iIhybPUKX6CwKJp6eqXHSTo
9EXxN0wS6Hl1T8NsGQkXT65WTU0ROPI+p96/jYT/AKY8VDQ=
     "]]}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwVxXs01GkYAGBZIpFkRkVy+cWS1EqcVLwvWrKlomwSuWxGndPpclJRscO4
jdoGYytpVJRLjUtbcVAKmwyW+BhKMwgzGWUQZRC7+8dzHpOQk96hykpKSp7/
+X8+OfT9VkY51De5hSNDDjd42c8zgiqg1tpZ/CBYDnFhQ1HXfqwEnjzASy9A
Dv4z5+Y4T5/B3d2DXqP75KBJpc3Htr6AgqmoJyXOcrB3GGA+UamFiO6smhBD
OfyZpM+6uU0ALSzTVckdI/CAW+tqK2yDivX4SrhjBHac/DlBYtELZ1hF/E9r
PoPdNsdqn3AJVLj56z+mPsEbWa7Q4s4nmAgeuzW+aRheflsdNpY/Bg7mOrNz
IIOOPzZdvV0/AVrXWczHYUMw0Rxk7mw1BRJawpcW9keQKdU9pEXPQJijd7Og
Ugo8t7P+5dfnQLw1se+8qhQKMw1fWEwrod2VPKdWDwnIePdDRZeVMVuyRRCR
MwhpKxqUH9JVMElRrmupPggvPkb6jr9UxeFTWmlNYQPQWNPsmr1HDVN2cgQH
3/aD/3iRtHFeHZ+kRBzf4dYPvjetYpfka2CyKPZlz7MPYLvL869yW02c21iY
lOryAbj7pm+Ke7WwLJ9h9rG2D1qP7Fp5/LQ2buCbq89490HDIC2/PHUp3imT
vlks7oWQjtYqAUMHK28Uxx471QtDHsHGV62XoXW7e+SlJb1ge8z+sLaqLl7K
uLw73asHjmuJJdubdfGERVRiVqYYuj8TWQKXhjYjufPbR0WgGandGH+MjkdJ
W1eHowis2YZfN9voYd/i1TnjvPewdPvp7/mLliMjrtg++ls3WG7VZZqJl2Pn
hrGs237dYFOW6PnrvRU4FK7U3PXPO5gVOX9zvbgSaV4cy6Et76CU3Tw86KqP
fJeL6d2lbyH3dMGhdHUDFOydU590eAu+Kg158yID9LvD7nIr6wKFwXMno/ur
8MZDJq/IuQsCxJOPZi4Zol1d2eyjuk4oMVtw6orbamTZmu7tOdAJDgV+BZaa
Rljt2UN/MyKEuE5FFeuDEcr+VjlcwhRC4Kun2h4+xsipsXTzNRRCQLhOUVG1
MZ6darjg8rQDzjnTkvXXmSCdMzEQ590Bal7My0EcE2RkttcdVLSDwk57RmXG
BNP0SElFZjuEBKilsAJNsTQtU6zr3g6S7NwQ9RpT7DwQHcX5SqDp+dGc4XUU
arJ74t/dJWBpkL6oIIXCGJ+zSht9CDzge4cy0ijUcDwi6N1HYJ2TTjWVTiFp
c6/ieBP4KfhqRNZ1Cq+NNlmN7CFgn5ck5WZROFk8Qiv8hYCLbdSraD6FWVT6
Clsk4LeTEbO/nkLueklhoBWB9+/XiHQaKJzKWSDRXUsg4ET/5pZGCkOZNI96
CwJBqUGjHi0UDjgtSLExJ8Do9AsEIYUnh1YZLzQhcOa3PY5rByiMiue6lOkR
mJjQypAOUhjHjjE/QSdwLqFp4p6UwkaV4U1mNAIXCjz4RsMUGubotHJ1CDDl
rgb0cQqhWKh6RpOAcozy+bYvFAakCrZZLSbAWlbdxpmk0P/WNK9/EYEEO6dk
DQWF9Lwp8X41AuqvZwdfT1NocbS0SmshAbZvpXP8LIXSdm59nQoBDVkkz2WO
Ql9v9uzvPxC4cnGzYn6ewi3uHD8HZQL/ApOLWZI=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.25701073988232714`},
  Method->{},
  PlotRange->{{0, 10}, {0.25701073988232714`, 0.9812762262329885}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.599762279269724*^9, {3.599765798824039*^9, 3.599765850968205*^9}, {
   3.599765930371385*^9, 3.599765983398067*^9}, 3.59976612424263*^9, 
   3.599766157303033*^9, {3.599766198693359*^9, 3.5997662385691423`*^9}, 
   3.5997663137106037`*^9, 3.59976643524105*^9, {3.599766514793353*^9, 
   3.599766522929318*^9}, 3.599766848407824*^9, {3.599766878864151*^9, 
   3.599766942468158*^9}, 3.59976710613402*^9, {3.599773554118515*^9, 
   3.599773563022593*^9}}],

Cell[BoxData[
 StyleBox["\<\"Credit spread: Exact (solid) vs our new code 2nd (Red) vs our \
new code 3rd (Green)\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{
  3.599580055316103*^9, 3.599647676217155*^9, 3.599647722472166*^9, 
   3.599647754841735*^9, {3.599647882766796*^9, 3.599647945533257*^9}, 
   3.599648858179399*^9, 3.5996488901201572`*^9, 3.5996489250088053`*^9, 
   3.5996489978921556`*^9, {3.599649051174417*^9, 3.599649065343054*^9}, {
   3.599649519756646*^9, 3.599649538266728*^9}, 3.5996495916539392`*^9, {
   3.599649837863709*^9, 3.5996498713541527`*^9}, 3.599649906167851*^9, 
   3.599649971306261*^9, 3.599761887325307*^9, 3.599761922966504*^9, {
   3.599762100171895*^9, 3.5997621210652122`*^9}, 3.599762278719192*^9, {
   3.599765798880405*^9, 3.59976585023072*^9}, {3.599765929798993*^9, 
   3.5997659828192663`*^9}, 3.5997661237548313`*^9, 3.599766156715291*^9, {
   3.599766198144003*^9, 3.599766237934782*^9}, 3.599766313078513*^9, 
   3.599766434609971*^9, {3.5997665142402563`*^9, 3.5997665223457747`*^9}, 
   3.599766847831785*^9, {3.599766878259441*^9, 3.599766941894169*^9}, 
   3.599767105481079*^9, {3.599773553366127*^9, 3.599773563024728*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVkWs0lAkYgBFLGiuMpMn1W9FKmyZWZ/G+os5Ol2O7WacII6Scyia5rDWI
jVAZW1HUtiXTSH1jhsYYM19uZUqhqWkzk5M77YWU3Jptfzzn+fn8eBzYR3ZE
6eno6Gz7zP+u6t47f7lEDPK+WLPNCgoull2TloTXQ9GY47fb2yk4GTOSdt5Z
AvX8LxKDH1IQMpv46YyoAS5/swli2iigEUXazE4ZaF4f0mY3UeC5vp8j1G+C
Pw0y1j2QUPDbqWVZpd4PIeHKODusioJb3CZ/5vMu+GlfxC5VAQXfH9mYM+jS
CweLJe+ntlLg4e1D7U4YBPR9Zj5jRsHT0YrnLlffgm3U2JXil3KQT9nGjFeO
Q/PdnSmTZXJQFqwrvPJgEt7Oq32EMXKY7Ahf4ef6EVqz93uErJbDqE4rn/7L
LPi9Y20c+lsGZZuOh4gvfIIR9/uCjjwZ3L5kI3OZ0cGmFNdgnr0MRstuRKlP
6+GiS+4Tt2SNULS0XY9vqY+pvYG1B9iNIBtODp6QG6Dh0TVxy7VSUNzv8L8W
aIjH6SlrLK9LIWSiekihNcK+3HQ9A38pBJe6Zn5ZaYzz2Zvt1w40AHPrNoGY
SUNdvztBPYUNwN05U6rpNcEoDk/x49oG6Ny/1Tou3hTTlkSfH+6RQPsAvVJ8
bjE6NQctds+QAFvZ2fgw2gwXqAKyX3/+MsKKsC90M8fugqISurIemLGe+0wN
LNC5XPK4NbUe4kw0gwEdFvg6z7RK7FIPr/7qHs3h0tHHit+c/UIMtGRTRXas
JS4SuZQWp4vBLdfmg5f7ElyQXxXLdRPD4oD4+cqFVsjg8O/ceXYPVn5nwXHS
WKEFN8ImKO0euNf9ui3o+lLkF2UOSlzvwZzab8o/1Rp5p+ciad11UJvbMTbg
vwxd86btFnHqoCKet7fYiIHKH1IUR1fXQbB++02tmoF2a+ecLitrYZoh9bW7
sRzjIzyYxzJrIVTznpz92QYveFzUmXeuhbtOukfzN9kiwzvk4/puEazn7eGt
pNnhFuuk/J50EZx8Md2Y9cYOXw6bjDs7iSCsRWTK2m2PfHpBzIanQghNMKuu
puxR7alKN0wQQqIfPW/ZKgd8zPCisayFYLidczr8jAN2Hu8/wWmugWkP01n9
WQd0czirk3ygBtihhmezwhzxSEG1MtO8BgavVbCN7jtieSQVDY0CeCQ98MfY
KgLNPiQo+tkCWMkoXsg7SyCzVTXYbCKAW1U7oqKLCNTdcduZRRPAKl8ziigm
sHv17KHHxgJYE1GYVH6BwBRrK63SUACeN08NccsJFJ1UBw7pCmADM63llyoC
w6wtrxp/IGHPluiMXQ8I9J7qsN2lIaGn5yu1WTuB1UsqVKoeEkIP93k9URAY
wik5H/qKhPBz4f+ynhDYVjNiG6MiIfrFnjB4/rkHsoiULhKORQb6fN1P4BRX
Kvy9lYTJSZOSoQECe5MowYoWEhJzHk1eHyIwqI8p4jeRkMJjVdmNERg6lNQm
kpPA+cefYTlB4PhSumN7PQl6GXonut4RyCpeHhAoJiHLnOo6855AC3XDwWd1
JOR4+OYZTxOoynzZohGSYNQ2N9A2Q6DUM3wmsoaE3GCJX/YcgRNRXOYISYLx
aHLZhk8EvvFOij98l4T8VK9prZbAuGEL4btqEv4D975Qcg==
     "]]}, 
   {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwVz3k41Akcx3EruXMrzIrxYxulWs84N/p+x3TZkkc1ZU3KPVs81WxtQqxN
kYjkqEj1SHKlrd8cZpw/R4ooKfbZ0IlCK5qIcezsH5/n/bz+/NCDDu8IVVZS
UvJS7P+Wd3Hnrl6RwG5V/iijjYLL+QU1VwKkYFfeoramlYLTvI+xOSuqwC1b
asd8RMFe+fH5dGE1nCzjZ7q3UKBNXFw41VkHjFTt5zsaKXByfR8vUGmEQiNn
+h9VFGSfNUvIdXsE0oyqgf4yCkozG9nM7mew22TNmDSVgi2HNyYOMl5DdEz2
ZrEnBY5u7hTn2CBYs/05jVoUPB0u6mbcGAWry5uT8p7UQ/3Uct548Ths3zW9
dFF6Pbw475B2/aEMDFgOOdyd9SDrCPiBteobFBSFhB80rIdhpQdlRnFy+CWZ
l9tQWgf5m37fK7k0D+aBOjyeSx3cyTOvY8woISsq1vJbTS0M598K7UtRRldV
dWsnr1q4aNKqXGasgrcZi8vWvq6Bug9RvhP1i1F/Nr26LLwG2ho62AXeatjy
W9J2UqkG9k5UDLUtqKPppjydurRq8M1ddUqnWBNj9qx9OGdZDcxtXvclTG2k
XX/enFtdBZk7Z3L7Xy/BO8ZvxyZ9qqAzZJtpBF8XLfgphVc/S6F1wKhYkqGH
bL1E35xkKQS96Kx9FKaP49rciEUrpPDRM9AybbUBanBau8LbJcA84LRPd7Eh
ao1mOIwdkkDEkv7BDR2GGMzvPu1hKoGXn7qGEzONUG6xdeJ+SyVoR+m2nTlg
jPz2ikE5vxJWJ5tPutgvxeyGEL8b1pWgt4E/V6yxDM+faGfc7RKD7TrDeJv+
Zej+aupfuyQx2IuTvHYXmmCoIHJ7pIcYZvtYU+wYU3Q0Xqn6z4wIRMkdIwNs
M3zZBPNiqQiK+CXcLHUa2u6J0QqOE4GvSuvthT4aUjcmn9aCCKZpNestbn2P
rC568Cc1Efj3f70nP2mO09aSy9AhhL9svjuSumk5RhrGipTzhOBa4ldiq22B
3FizSPtwIZzuma5NeGuBd4HpPeMqhP3NQl1PjiVmr7JqitYRgv8x/YoKyhK1
etTKP70RwHGW0TkzOzomcL5wqyoFoOYTnxKQTsdIXty5+CwBTDvqylXkdJTr
1fafPSyAIH+1Cwn7rbDTz/eFubcABguKgtQbrLAs756Di70AHtf8enPEjsBG
FdnVxwYCsKVlaZRcINArf4um8zcSSst3hIZdJHDu51ybpikS7NbrU0QWgURO
XaCPwj8Gpp24dolA51MhbhGTJDjdPjuUeY3ARX8zo2/KSPBgxjbHlRNYktSs
ZzJOgt/WsD93PSRwaiv3iOkwCb291n36rQTapHjmlH4kwf/QO5cnbQTSR1V6
1ykckBHw2fMJgezP1IN9H0gI6/HbD90EpjdHmBQNknA02Nt95XsCm8Vw66d3
JMhkS64MDRC4MYTW1P6WhOOJj2WFQwQeXQrKgQpHl3iWW4wQeM/UvTfpDQnx
Y2ya8QSBHBdb1Z5XJCj/qRz57AuBXLHf8nCFEwyoZ+lfFf+dMzgL/SQkOq4/
pzlNYFvhiCVDYfWW2YGWGQI3U/OC6j4Skn2rWGdmCdTArzwfhTWHo/I95glc
IXrgOthLQmqMy/TCAoHJ4oMrYxT+D/SuSQo=
     "]]}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwVj3s0lAkYh6dJmVzWXUVy+RKWVGt1tMX7uqTckoqcSiaFOnWyLYtSc0RN
SZnckko6ymWEzefWGGPmU0NGOxoVySXJJVNtsSTErP3jd57z/PWcn2lIxM5Q
Oo1G85nf/yx5sW/2djYP0raZSSY6KbiRkyfIZtbCgFllWMRrCs6Hj5y9bsGH
M9zVbqPtFOyfiZ7jVNWBk2uenupLCtSINEWCTAgub64vviSlYMPGgfhKpcfQ
b3uiYNcTCjIvGSTe3NwMctK2RFJOQXH6Y1e79jZwi1rYMsqhYFvEFvaQZR/U
T3VNoxcF9psdKf+oIaDXeV10Uqfgubyg3fLuJ2i7934yUyYC0eTK8NGiUSjW
jD0tTxXBq6u/puQ+HQeHmO+0o3tEMC5lrna2/g4rzCOqp5eJQE5rfKDLmoFU
Ad10N08IOe5/7udlzUF5ZYPDFU8hlN4yElpO03BW0Un5vawHeU5+aE8yHfnP
HTt44fWQtkxCf6CnhFoMZtQ/cwIQfjgVOCZahNSXHgM9jgBaGqSueb7KuGft
1tg/LAWwf6xsuEXBQOGQgKvJr4PAm9YJPxWpYFfEET2OXx3YefuQPDs1bM65
/Un2lQ/pu6Zv9vap4x52wLuyJD7IDnsvP35SAxfms/u1rfkgGdQt4qVq4jE9
9A5orIWQV7L65jAt1JK4gH1oLYx4HDRJWaONpsOp+RZqtWB3dMMBjUU6GLzA
1te9lAfH1XuH3KQ62GrB3bkpgAddn1/I2em6uCXdRuRH54HaKY2WC0f1UDkP
DnUWPYI1SUbfHNbr40RjeVZLwCPQdDs5W7RkKd6qa1gYrqgBq0068ea9S9H+
xDGm6YMaWF9z0Sfg/jJcM3hO1h1UAz96nCdd45Zjlr5nPUu1BqqTpB8HXQ2w
OdJ/QC6shoKT3H0ZDEMUv2PZMWKqIVBJUqjoMcQl3fJkV6tqmDIUOBnnr0CN
t8Ix+bsqCOqdKJ85Y4TvPV+792ZWwUPzBb9fcV+JvKetu1V3VMFG7l6ulZox
dt6XzpWqVcH5jqn6xH5j9KhjPfv7SSUEi6s0PPxNMLL/c4EsoRKCorTKyigT
TLwjTYnbXAnRzrqXDWxM8WpuxZPM7xWg7BefzOSYoq/FIVWX2gqYsteYUZox
xcJbvyymYiogJEj5WmKwGZo7snoLf6uAobyCEEaDGVrRH8YXK0h4Jjhy76MN
gevX5UuLRCRYGWYs4V4jEHJLopvYJBSX7AwNSyPw6nO72cYLJNg4aVFEBoGl
IfKMxvMkrDuYEnsni8B4w7eT4gQSNhReGk6/Q+AbBi9ZzCLBxe6smFVC4I1S
0UhTNAl7vcLO7X5K4MXFNZGdYSR0d6/q0ZIQODhMM+oKJSHoxHuH1hYCtTXd
O7oPk8BMZX71aCXwQx2f1RdCQljH3mBoJ9DZ2yL7wwESIg/5Ov48QODdz5nT
MwEkjI+rZw8PEqif0kbO+ZMQzX42fn+YQJfir3EL5v0016PE+COBtBEJKu8i
If6Lq6HeGIEq1yQZOr4k0M/RY9r+JdDaaOiF/nYSErWpNs7EfH9HO2HgQwLb
3umyytT8PzfbbyZeJDCafgw2TRPYJ0uLXeVJQlIg3/nCDwIZuWJVSw8SVOSn
clzmCFylI/7LehsJV+IcphQKAjdlcg6v3UrCf5fgUsk=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.03139869796132818},
  Method->{},
  PlotRange->{{0, 10}, {0.03139869796132818, 0.13946411485500626`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.599762279269724*^9, {3.599765798824039*^9, 3.599765850968205*^9}, {
   3.599765930371385*^9, 3.599765983398067*^9}, 3.59976612424263*^9, 
   3.599766157303033*^9, {3.599766198693359*^9, 3.5997662385691423`*^9}, 
   3.5997663137106037`*^9, 3.59976643524105*^9, {3.599766514793353*^9, 
   3.599766522929318*^9}, 3.599766848407824*^9, {3.599766878864151*^9, 
   3.599766942468158*^9}, 3.59976710613402*^9, {3.599773554118515*^9, 
   3.599773563732622*^9}}],

Cell["\<\
Explicit expressions of the bond price expansion:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599572470029501*^9, 3.599572470582589*^9}, {
   3.599579629345312*^9, 3.599579757268725*^9}, {3.5997633116146307`*^9, 
   3.599763324675173*^9}}],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", ",", 
   "c"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Bondbar", "[", "0", "]"}], "[", 
   RowBox[{
   "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", ",", 
    "c"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Bondbar", "[", "1", "]"}], "[", 
   RowBox[{
   "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", ",", 
    "c"}], "]"}], "//", "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Bondbar", "[", "2", "]"}], "[", 
   RowBox[{
   "T", ",", "S0", ",", "r", ",", "\[Sigma]", ",", "\[Beta]", ",", "b", ",", 
    "c"}], "]"}], "//", "Simplify"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, 3.5995800475001183`*^9, 3.599580084720087*^9, {
   3.5996472759375553`*^9, 3.599647303863413*^9}, {3.5996492071107883`*^9, 
   3.599649223589286*^9}, {3.5996497890550528`*^9, 3.599649789546336*^9}, {
   3.599761168021061*^9, 3.599761247760721*^9}, {3.599762345488532*^9, 
   3.599762356956126*^9}, {3.59981525572113*^9, 3.599815279952796*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{
   RowBox[{"-", "T"}], " ", 
   RowBox[{"(", 
    RowBox[{"b", "+", 
     RowBox[{"c", " ", 
      SuperscriptBox["S0", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
      SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}]]], "Output",
 CellChangeTimes->{{3.59957772402394*^9, 3.5995777284103117`*^9}, 
   3.5995799245957747`*^9, {3.599579955759563*^9, 3.599579974414955*^9}, 
   3.59958001084453*^9, 3.599580086885993*^9, {3.5996491876557283`*^9, 
   3.5996492238224373`*^9}, {3.599649770241008*^9, 3.5996497908289957`*^9}, {
   3.599761196168851*^9, 3.5997612483673697`*^9}, {3.599762350193882*^9, 
   3.599762357501978*^9}, 3.5997658564262877`*^9, 3.5997749014033527`*^9, {
   3.5998152654019747`*^9, 3.5998152849754066`*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "T"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      RowBox[{"c", " ", 
       SuperscriptBox["S0", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
       SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}]], " ", 
  RowBox[{"(", 
   RowBox[{"2", "-", 
    RowBox[{"c", " ", 
     SuperscriptBox["S0", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
     SuperscriptBox["T", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], " ", 
     SuperscriptBox["\[Sigma]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "b"}], "+", 
       RowBox[{"2", " ", "r"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "c"}]}], ")"}], " ", 
        SuperscriptBox["S0", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
        SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.59957772402394*^9, 3.5995777284103117`*^9}, 
   3.5995799245957747`*^9, {3.599579955759563*^9, 3.599579974414955*^9}, 
   3.59958001084453*^9, 3.599580086885993*^9, {3.5996491876557283`*^9, 
   3.5996492238224373`*^9}, {3.599649770241008*^9, 3.5996497908289957`*^9}, {
   3.599761196168851*^9, 3.5997612483673697`*^9}, {3.599762350193882*^9, 
   3.599762357501978*^9}, 3.5997658564262877`*^9, 3.5997749014033527`*^9, {
   3.5998152654019747`*^9, 3.599815285091845*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "T"}], " ", 
    RowBox[{"(", 
     RowBox[{"b", "+", 
      RowBox[{"c", " ", 
       SuperscriptBox["S0", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
       SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}]], " ", 
  RowBox[{"(", 
   RowBox[{"2", "-", 
    RowBox[{"c", " ", 
     SuperscriptBox["S0", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
     SuperscriptBox["T", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], " ", 
     SuperscriptBox["\[Sigma]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "b"}], "+", 
       RowBox[{"2", " ", "r"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "c"}]}], ")"}], " ", 
        SuperscriptBox["S0", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
        SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox["1", "12"], " ", "c", " ", 
     SuperscriptBox["S0", 
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Beta]"}], ")"}], "2"], " ", 
     SuperscriptBox["\[Sigma]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "24"}], " ", 
        SuperscriptBox["S0", 
         RowBox[{"4", "+", 
          RowBox[{"2", " ", "\[Beta]"}]}]], " ", 
        SuperscriptBox["\[Sigma]", "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["S0", 
         RowBox[{"2", "+", 
          RowBox[{"4", " ", "\[Beta]"}]}]], " ", "T", " ", 
        SuperscriptBox["\[Sigma]", "4"]}], "+", 
       RowBox[{"48", " ", "c", " ", 
        SuperscriptBox["S0", 
         RowBox[{"2", "+", 
          RowBox[{"4", " ", "\[Beta]"}]}]], " ", "T", " ", 
        SuperscriptBox["\[Sigma]", "4"]}], "-", 
       RowBox[{"32", " ", 
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox["S0", 
         RowBox[{"2", "+", 
          RowBox[{"4", " ", "\[Beta]"}]}]], " ", "T", " ", 
        SuperscriptBox["\[Sigma]", "4"]}], "+", 
       RowBox[{"3", " ", "c", " ", 
        SuperscriptBox["S0", 
         RowBox[{"6", " ", "\[Beta]"}]], " ", 
        SuperscriptBox["T", "2"], " ", 
        SuperscriptBox["\[Sigma]", "6"]}], "-", 
       RowBox[{"12", " ", 
        SuperscriptBox["c", "2"], " ", 
        SuperscriptBox["S0", 
         RowBox[{"6", " ", "\[Beta]"}]], " ", 
        SuperscriptBox["T", "2"], " ", 
        SuperscriptBox["\[Sigma]", "6"]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["c", "3"], " ", 
        SuperscriptBox["S0", 
         RowBox[{"6", " ", "\[Beta]"}]], " ", 
        SuperscriptBox["T", "2"], " ", 
        SuperscriptBox["\[Sigma]", "6"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["b", "2"], " ", 
        SuperscriptBox["S0", "4"], " ", "T", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["S0", "2"]}], "-", 
          RowBox[{"3", " ", "c", " ", 
           SuperscriptBox["S0", 
            RowBox[{"2", " ", "\[Beta]"}]], " ", "T", " ", 
           SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["S0", "4"], " ", "T", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           SuperscriptBox["S0", "2"]}], "-", 
          RowBox[{"3", " ", "c", " ", 
           SuperscriptBox["S0", 
            RowBox[{"2", " ", "\[Beta]"}]], " ", "T", " ", 
           SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}], "+", 
       RowBox[{"12", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"2", " ", "c"}]}], ")"}], " ", "r", " ", 
        SuperscriptBox["S0", 
         RowBox[{"2", "+", 
          RowBox[{"2", " ", "\[Beta]"}]}]], " ", "T", " ", 
        SuperscriptBox["\[Sigma]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox["S0", "2"]}], "+", 
          RowBox[{"c", " ", 
           SuperscriptBox["S0", 
            RowBox[{"2", " ", "\[Beta]"}]], " ", "T", " ", 
           SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}], "-", 
       RowBox[{"4", " ", "b", " ", 
        SuperscriptBox["S0", "2"], " ", "T", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "c"}]}], ")"}], " ", 
           SuperscriptBox["S0", 
            RowBox[{"2", " ", "\[Beta]"}]], " ", 
           SuperscriptBox["\[Sigma]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", 
              SuperscriptBox["S0", "2"]}], "+", 
             RowBox[{"c", " ", 
              SuperscriptBox["S0", 
               RowBox[{"2", " ", "\[Beta]"}]], " ", "T", " ", 
              SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"8", " ", 
              SuperscriptBox["S0", "4"]}], "-", 
             RowBox[{"6", " ", "c", " ", 
              SuperscriptBox["S0", 
               RowBox[{"2", "+", 
                RowBox[{"2", " ", "\[Beta]"}]}]], " ", "T", " ", 
              SuperscriptBox["\[Sigma]", "2"]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.59957772402394*^9, 3.5995777284103117`*^9}, 
   3.5995799245957747`*^9, {3.599579955759563*^9, 3.599579974414955*^9}, 
   3.59958001084453*^9, 3.599580086885993*^9, {3.5996491876557283`*^9, 
   3.5996492238224373`*^9}, {3.599649770241008*^9, 3.5996497908289957`*^9}, {
   3.599761196168851*^9, 3.5997612483673697`*^9}, {3.599762350193882*^9, 
   3.599762357501978*^9}, 3.5997658564262877`*^9, 3.5997749014033527`*^9, {
   3.5998152654019747`*^9, 3.599815285679619*^9}}]
}, Open  ]]
},
WindowSize->{1440, 852},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[1463, 33, 764, 12, 86, "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[2252, 49, 197, 4, 68, "Section"],
Cell[2452, 55, 1352, 26, 220, "Text"],
Cell[3807, 83, 377, 5, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[4187, 90, 7908, 258, 417, "DisplayFormula"],
Cell[12098, 350, 840, 13, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[12941, 365, 4738, 128, 313, "Input"],
Cell[17682, 495, 787, 12, 35, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[18472, 509, 6459, 156, 372, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[24934, 667, 522, 7, 35, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[25459, 676, 6667, 151, 385, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[32129, 829, 1401, 25, 25, "Print"],
Cell[33533, 856, 6116, 109, 241, "Output"],
Cell[39652, 967, 1402, 25, 25, "Print"],
Cell[41057, 994, 6116, 109, 240, "Output"],
Cell[47176, 1105, 676, 11, 35, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[47855, 1118, 2500, 46, 96, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[50358, 1166, 837, 18, 38, "Output"],
Cell[51198, 1186, 1700, 46, 47, "Output"],
Cell[52901, 1234, 6370, 172, 122, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature fwpm26JJgj4TdA1kVrCvjTkF *)
