(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 9.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1063,         20]
NotebookDataLength[     53432,       1268]
NotebookOptionsPosition[     52665,       1232]
NotebookOutlinePosition[     53030,       1248]
CellTagsIndexPosition[     52987,       1245]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Implied volatility expansion for the 3/2 model (",
 StyleBox["only short maturities",
  FontVariations->{"Underline"->True}],
 ")"
}], "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{{3.597959818770582*^9, 3.597959888695898*^9}, {
   3.598691843796198*^9, 3.598691878784575*^9}, {3.598692123374341*^9, 
   3.598692149185072*^9}, {3.598695685015595*^9, 3.598695691334046*^9}, 
   3.598697015690859*^9, {3.598697566849069*^9, 3.598697567706442*^9}, {
   3.598982961426049*^9, 3.598982962721182*^9}, {3.5991317618057747`*^9, 
   3.599131764686119*^9}, {3.5995682782076883`*^9, 3.599568284377194*^9}, {
   3.59975756316742*^9, 3.59975756390152*^9}, {3.599757849348279*^9, 
   3.599757858156934*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Disclaimer", "Subtitle",
 FontSize->14]], "Section",
 CellChangeTimes->{
  3.5125543173858905`*^9, {3.5127369729216976`*^9, 3.5127369760808783`*^9}},
 TextAlignment->Center],

Cell["\<\
Date: 25/01/2014

This file was created by: Matthew Lorig, Stefano Pagliarani and Andrea \
Pascucci.

These Mathematica notebooks are provided on an \[OpenCurlyDoubleQuote]as is\
\[CloseCurlyDoubleQuote] basis without warranty of any kind, express or \
implied. Under no circumstances and under no legal theory, whether in tort, \
contract, or otherwise, shall the authors be liable to you or to any other \
person for any indirect, special, incidental, or consequential damages or \
losses. If you do not agree with these terms, then you are advised to not use \
the notebooks.

Please do no redistribute these notebooks.  If you wish to endorse the \
notebooks, then please link to the web-pages of the authors:
http://www.princeton.edu/~mlorig/
http://www.math.unipd.it/~stefanop/
http://www.dm.unibo.it/~pascucci/\
\>", "Text",
 CellChangeTimes->{{3.5127369954359856`*^9, 3.512737125359417*^9}, {
   3.5127371655637164`*^9, 3.5127371663597617`*^9}, {3.512814058730217*^9, 
   3.512814058891226*^9}, 3.526199505602*^9, 3.5268335032155323`*^9, {
   3.5272388928125*^9, 3.527238893671875*^9}, {3.5804506352987995`*^9, 
   3.580450646016018*^9}, 3.5804510585431423`*^9, 3.5804621638150606`*^9, {
   3.5807902968427057`*^9, 3.580790297139106*^9}, {3.590203507604435*^9, 
   3.590203507894435*^9}, {3.599580220348298*^9, 3.599580226144642*^9}}]
}, Open  ]],

Cell["The model:", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   StyleBox[
    RowBox[{"     ", 
     StyleBox[" ",
      FontWeight->"Bold"]}]], 
   StyleBox[
    RowBox[{
     FormBox[
      RowBox[{
       RowBox[{"d", " ", 
        SubscriptBox["S", "t"]}], "=", 
       RowBox[{
        RowBox[{"r", " ", 
         SubscriptBox["S", "t"], "dt"}], "+", 
        RowBox[{
         SqrtBox[
          SubscriptBox["v", "t"]], " ", 
         SubscriptBox["S", "t"], 
         SubscriptBox["dW", "t"]}]}]}],
      TraditionalForm], "\[IndentingNewLine]", 
     FormBox[
      RowBox[{"  ", 
       RowBox[{
        RowBox[{"d", " ", 
         SubscriptBox["v", "t"]}], "=", 
        RowBox[{
         SubscriptBox["v", "t"], "(", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Kappa]", "(", 
            RowBox[{"\[Theta]", "-", 
             SubscriptBox["v", "t"]}], ")"}], "dt"}], "+", " ", 
          RowBox[{"\[Delta]", " ", 
           SqrtBox[
            SubscriptBox["v", "t"]], 
           SubscriptBox["dB", "t"]}]}]}]}]}],
      TraditionalForm]}],
    FontWeight->"Bold"], 
   StyleBox[")",
    FontWeight->"Bold"]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["v", "0"], "=", 
  RowBox[{"initial", " ", "variance"}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubscriptBox["S", "0"], "=", 
  RowBox[{"initial", " ", "asset", " ", "value"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", 
   RowBox[{"interest", " ", "rate"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"\[Kappa]", "=", 
  RowBox[{
  "speed", " ", "of", " ", "mean", " ", 
   "reversion"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Theta]", "=", 
  RowBox[{"long", "-", 
   RowBox[{"term", " ", "variance"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Delta]", "=", 
  RowBox[{"vol", " ", "of", " ", "vol"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Rho]", "=", "correlation"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"K", "=", " ", "strike"}]}], "DisplayFormula",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQLRHve+/9hVeOW5T9noNoK6vsNyD63qobP0F0z6eH
jB+AdMOHWSwg+to/bW4Q/YjhMg+I3qDKPO87Ei30Im4LiG7+6bwdRCsdED0B
oqcIFV0B0X4qe9+D6KPOlv9AtFpNTtHCi68cn5QuqATRflWrWkB0DsuuHhA9
gWnOBBDdGfd1Mog+EzAnZDGQVviRkAiiS0vDT4PoT68unQXRd+9/lVgCpJ9Z
xUqD6KC/cvIgWmOeqyKInmcUZASipxSnW4JovbTrP5cCabvzL8H0vJjj/44D
aRe1i2Ba5E1s6l+Q+OxvYPrb1Iu1ILrk3V0w/d9Eikvk0ivHXZ/+g2kAwQ3N
bQ==
  "],
 FontFamily->"Times New Roman",
 FontSize->14,
 Background->RGBColor[1, 1, 0.85]],

Cell["\<\
Define the n-th order implied vol. expansion \[Sigma]bar[n][T, S0, K, v0, r, \
... ]:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.599571888346801*^9}, {3.59957336260646*^9, 3.599573364659486*^9}, {
   3.599573763220446*^9, 3.599573820048551*^9}, 3.599765256369031*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Get", "[", 
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", 
    "\"\<coefficients_IV_order4_three_halves\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "T", ",", "S0", ",", "v0", ",", "r", ",", "\[Kappa]", ",", "\[Theta]", ",",
     "\[Delta]", ",", "\[Rho]"}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"uBS", "[", 
    RowBox[{"T_", ",", "x_", ",", "k_", ",", "\[Sigma]_", ",", "r_"}], "]"}], 
   ":=", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", "x"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"Erf", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "k"}], "+", 
            RowBox[{"r", " ", "T"}], "+", "x", "+", 
            FractionBox[
             RowBox[{"T", " ", 
              SuperscriptBox["\[Sigma]", "2"]}], "2"]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["T"], " ", "\[Sigma]"}]], "]"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"k", "-", 
         RowBox[{"r", " ", "T"}]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"Erfc", "[", 
          FractionBox[
           RowBox[{
            RowBox[{"-", "k"}], "+", 
            RowBox[{"r", " ", "T"}], "+", "x", "-", 
            FractionBox[
             RowBox[{"T", " ", 
              SuperscriptBox["\[Sigma]", "2"]}], "2"]}], 
           RowBox[{
            SqrtBox["2"], " ", 
            SqrtBox["T"], " ", "\[Sigma]"}]], "]"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\n", 
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"j", "=", "0"}], ",", 
   RowBox[{"j", "\[LessEqual]", "4"}], ",", 
   RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"uBS\[Sigma]", "[", "j", "]"}], "[", 
      RowBox[{"T_", ",", "x_", ",", "k_", ",", "\[Sigma]_", ",", "r_"}], 
      "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"uBS", "[", 
           RowBox[{"T", ",", "x", ",", "k", ",", "\[Sigma]", ",", "r"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Sigma]", ",", "j"}], "}"}]}], "]"}], "/", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"uBS", "[", 
           RowBox[{"T", ",", "x", ",", "k", ",", "\[Sigma]", ",", "r"}], 
           "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Sigma]", ",", "1"}], "}"}]}], "]"}]}], "//", 
       "Simplify"}], "//", "Evaluate"}]}], " ", ";"}]}], 
  "\[IndentingNewLine]", "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
    RowBox[{"T_", ",", "x_", ",", "k_", ",", "y_", ",", "r_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       FractionBox["1", "T"], "2", 
       RowBox[{
        RowBox[{"aI", "[", 
         RowBox[{"2", ",", "0"}], "]"}], "[", 
        RowBox[{"0", ",", "T"}], "]"}]}]], "//", "FullSimplify"}], "//", 
    "Evaluate"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]bar", "[", "0", "]"}], "[", 
    RowBox[{
    "T_", ",", "S0_", ",", "K_", ",", "v0_", ",", "r_", ",", "\[Kappa]_", ",",
      "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
      RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "\[Rule]", 
        RowBox[{"Log", "[", "S0", "]"}]}], ",", 
       RowBox[{"y", "\[Rule]", 
        RowBox[{"Log", "[", "v0", "]"}]}], ",", 
       RowBox[{"k", "\[Rule]", 
        RowBox[{"Log", "[", "K", "]"}]}]}], "}"}]}], "//", "Evaluate"}]}], 
  ";"}], "\n", 
 RowBox[{"For", "[", " ", 
  RowBox[{
   RowBox[{"n", "=", "1"}], ",", 
   RowBox[{"n", "\[LessEqual]", "4"}], ",", 
   RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]", "[", "n", "]"}], "[", 
      RowBox[{"T_", ",", "x_", ",", "k_", ",", "y_", ",", "r_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", 
         RowBox[{"T", " ", 
          RowBox[{
           RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
           RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}]}]], 
        RowBox[{"(", 
         RowBox[{
          UnderoverscriptBox["\[Sum]", 
           RowBox[{"h", "=", "1"}], "n"], 
          RowBox[{
           UnderoverscriptBox["\[Sum]", 
            RowBox[{"i", "=", "0"}], 
            RowBox[{
             RowBox[{
              RowBox[{"dimFIV", "[", 
               RowBox[{"n", ",", "h"}], "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}], "-", "1"}]], 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"FIV", "[", 
               RowBox[{"n", ",", "h"}], "]"}], "[", "T", "]"}], "[", 
             RowBox[{"[", 
              RowBox[{
               RowBox[{"i", "+", "1"}], ",", "1", ",", "1"}], "]"}], "]"}], 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"-", "1"}], 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
                 RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], 
                SqrtBox[
                 RowBox[{"2", " ", "T"}]]}]], ")"}], "i"], 
            RowBox[{"HermiteH", "[", 
             RowBox[{"i", ",", 
              FractionBox[
               RowBox[{"x", "+", 
                RowBox[{"r", " ", "T"}], "-", "k", "-", 
                RowBox[{
                 FractionBox["1", "2"], 
                 SuperscriptBox[
                  RowBox[{
                   RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
                   RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], 
                   "]"}], "2"], "T"}]}], 
               RowBox[{
                RowBox[{
                 RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
                 RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], 
                SqrtBox[
                 RowBox[{"2", " ", "T"}]]}]]}], "]"}]}]}]}], ")"}]}], "-", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"n", "!"}]], 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"h", "=", "2"}], "n"], 
         RowBox[{
          RowBox[{"BellY", "[", 
           RowBox[{"n", ",", "h", ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"mm", "!"}], 
               RowBox[{
                RowBox[{"\[Sigma]", "[", "mm", "]"}], "[", 
                RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], 
                "]"}]}], ",", 
              RowBox[{"{", 
               RowBox[{"mm", ",", 
                RowBox[{"n", "-", "h", "+", "1"}]}], "}"}]}], "]"}]}], "]"}], 
          
          RowBox[{
           RowBox[{"uBS\[Sigma]", "[", "h", "]"}], "[", 
           RowBox[{"T", ",", "x", ",", "k", ",", 
            RowBox[{
             RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
             RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], 
            ",", "r"}], "]"}]}]}]}]}], "//", "Evaluate"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]bar", "[", "n", "]"}], "[", 
      RowBox[{
      "T_", ",", "S0_", ",", "K_", ",", "v0_", ",", "r_", ",", "\[Kappa]_", 
       ",", "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Sigma]", "[", "0", "]"}], "[", 
         RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}], "+", 
        RowBox[{
         UnderoverscriptBox["\[Sum]", 
          RowBox[{"j", "=", "1"}], "n"], 
         RowBox[{
          RowBox[{"\[Sigma]", "[", "j", "]"}], "[", 
          RowBox[{"T", ",", "x", ",", "k", ",", "y", ",", "r"}], "]"}]}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x", "\[Rule]", 
          RowBox[{"Log", "[", "S0", "]"}]}], ",", 
         RowBox[{"y", "\[Rule]", 
          RowBox[{"Log", "[", "v0", "]"}]}], ",", 
         RowBox[{"k", "\[Rule]", 
          RowBox[{"Log", "[", "K", "]"}]}]}], "}"}]}], "//", "Evaluate"}]}], 
    ";"}]}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, 3.599572044926639*^9, {
   3.599572597475325*^9, 3.599572606896727*^9}, {3.5995732926543293`*^9, 
   3.599573323590609*^9}, {3.5995736484401913`*^9, 3.599573655595448*^9}, {
   3.599573689680131*^9, 3.599573689998679*^9}, {3.599573723420217*^9, 
   3.5995737548972692`*^9}, {3.599574349145996*^9, 3.599574403392612*^9}, {
   3.59957702493897*^9, 3.599577098077257*^9}, {3.59957988568289*^9, 
   3.599579892355043*^9}, {3.5996442989827747`*^9, 3.599644303150548*^9}, {
   3.599644915637518*^9, 3.5996449332744102`*^9}, {3.5996450003593616`*^9, 
   3.5996450119383593`*^9}, {3.599646828696809*^9, 3.599646849580553*^9}, {
   3.599756149153285*^9, 3.5997561535316153`*^9}, {3.5997562650978117`*^9, 
   3.599756265291934*^9}, {3.599756877799437*^9, 3.599756886469398*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell["\<\
Define the call option price (via numerical integration) and the implied \
volatility (via B&S inversion) for the comparison:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599575770106182*^9, 3.599575770445821*^9}, {
   3.599765266279035*^9, 3.5997652826840754`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "T", ",", "S0", ",", "v0", ",", "r", ",", "\[Kappa]", ",", "\[Theta]", ",",
     "\[Delta]", ",", "\[Rho]", ",", "r"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CallLog", "[", "32", "]"}], "[", 
    RowBox[{
    "x_", ",", "k_", ",", "t_", ",", "v0_", ",", "\[Kappa]_", ",", 
     "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_", ",", "r_"}], "]"}], ":=", 
   
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "p", ",", "q", ",", "\[Alpha]0", ",", "\[Gamma]", ",", "\[CapitalPhi]0",
        ",", "h", ",", "z", ",", "\[Lambda]i"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"p", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{
        RowBox[{"-", "\[Kappa]"}], " ", "+", " ", 
        RowBox[{
        "\[ImaginaryI]", " ", "\[Delta]", " ", "\[Rho]", " ", 
         "\[Lambda]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"q", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{
        FractionBox["1", "2"], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "\[Lambda]"}], " ", "+", " ", 
          RowBox[{"\[Lambda]", "^", "2"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Alpha]0", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "2"], "-", 
           FractionBox[
            RowBox[{"p", "[", "\[Lambda]", "]"}], 
            RowBox[{"\[Delta]", "^", "2"}]]}], ")"}]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             FractionBox["1", "2"], "-", 
             FractionBox[
              RowBox[{"p", "[", "\[Lambda]", "]"}], 
              RowBox[{"\[Delta]", "^", "2"}]]}], ")"}], "^", "2"}], "+", 
          RowBox[{"2", " ", 
           FractionBox[
            RowBox[{"q", "[", "\[Lambda]", "]"}], 
            RowBox[{"\[Delta]", "^", "2"}]]}]}]]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[Gamma]", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{"2", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Alpha]0", "[", "\[Lambda]", "]"}], "+", "1", "-", 
          FractionBox[
           RowBox[{"p", "[", "\[Lambda]", "]"}], 
           RowBox[{"\[Delta]", "^", "2"}]]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"z", "=", 
       RowBox[{
        FractionBox["v0", 
         RowBox[{"\[Kappa]", " ", "\[Theta]"}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{"\[Kappa]", " ", "\[Theta]", " ", "t"}], "]"}], "-", "1"}],
          ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[CapitalPhi]0", "[", "\[Lambda]_", "]"}], "=", 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{"\[ImaginaryI]", " ", "\[Lambda]", " ", 
          RowBox[{"(", 
           RowBox[{"x", "+", 
            RowBox[{"r", " ", "t"}]}], ")"}]}], "]"}], 
        FractionBox[
         RowBox[{"Gamma", "[", 
          RowBox[{
           RowBox[{"\[Gamma]", "[", "\[Lambda]", "]"}], "-", 
           RowBox[{"\[Alpha]0", "[", "\[Lambda]", "]"}]}], "]"}], 
         RowBox[{"Gamma", "[", 
          RowBox[{"\[Gamma]", "[", "\[Lambda]", "]"}], "]"}]], 
        RowBox[{
         RowBox[{"(", 
          FractionBox["2", 
           RowBox[{
            RowBox[{"\[Delta]", "^", "2"}], " ", "z"}]], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{"\[Alpha]0", "[", "\[Lambda]", "]"}], ")"}]}], 
        RowBox[{"Hypergeometric1F1", "[", 
         RowBox[{
          RowBox[{"\[Alpha]0", "[", "\[Lambda]", "]"}], ",", 
          RowBox[{"\[Gamma]", "[", "\[Lambda]", "]"}], ",", 
          FractionBox[
           RowBox[{"-", "2"}], 
           RowBox[{
            RowBox[{"\[Delta]", "^", "2"}], " ", "z"}]]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"h", "[", "\[Lambda]_", "]"}], "=", 
       FractionBox[
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"k", "-", 
           RowBox[{"\[ImaginaryI]", " ", "k", " ", "\[Lambda]"}]}]]}], 
        RowBox[{" ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", "\[Lambda]"}], "+", 
           SuperscriptBox["\[Lambda]", "2"]}], ")"}]}]]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Lambda]i", "=", 
       RowBox[{"-", "1.25"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       FractionBox[
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "r"}], " ", "t"}], "]"}], 
        RowBox[{"2", "\[Pi]"}]], 
       RowBox[{"Chop", "[", 
        RowBox[{"NIntegrate", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Re", "[", 
           RowBox[{
            RowBox[{"\[CapitalPhi]0", "[", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"\[ImaginaryI]", " ", "\[Lambda]i"}]}], "]"}], 
            RowBox[{"h", "[", 
             RowBox[{"\[Lambda]", "+", 
              RowBox[{"\[ImaginaryI]", " ", "\[Lambda]i"}]}], "]"}]}], "]"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]", ",", 
            RowBox[{"-", "\[Infinity]"}], ",", "\[Infinity]"}], "}"}], ",", 
          RowBox[{"Method", " ", "->", "\"\<GlobalAdaptive\>\""}], ",", 
          RowBox[{"Exclusions", "\[Rule]", "0"}], ",", 
          RowBox[{"WorkingPrecision", " ", "\[Rule]", "13"}]}], "]"}], 
        "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Call", " ", "price", " ", "as", " ", "a", " ", "function", " ", "of", " ",
     "price", " ", "S0", " ", "and", " ", "strike", " ", "K"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Call", "[", "32", "]"}], "[", 
    RowBox[{
    "S0_", ",", "K_", ",", "T_", ",", "v0_", ",", "\[Kappa]_", ",", 
     "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_", ",", "r_"}], "]"}], ":=", 
   
   RowBox[{
    RowBox[{"CallLog", "[", "32", "]"}], "[", 
    RowBox[{
     RowBox[{"Log", "[", "S0", "]"}], ",", 
     RowBox[{"Log", "[", "K", "]"}], ",", "T", ",", "v0", ",", "\[Kappa]", 
     ",", "\[Theta]", ",", "\[Delta]", ",", "\[Rho]", ",", "r"}], "]"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Implied", " ", "volatility"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImpVol", "[", 
    RowBox[{"CallPrice_", ",", " ", "S0_", ",", "K_", ",", "T_", ",", "r_"}], 
    "]"}], " ", ":=", " ", 
   RowBox[{"FinancialDerivative", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\"\<European\>\"", ",", " ", "\"\<Call\>\""}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<StrikePrice\>\"", " ", "->", " ", "K"}], ",", " ", 
       RowBox[{"\"\<Expiration\>\"", " ", "->", " ", "T"}], ",", " ", 
       RowBox[{"\"\<Value\>\"", " ", "->", " ", "CallPrice"}]}], "}"}], ",", 
     "  ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\"\<InterestRate\>\"", " ", "->", " ", "r"}], ",", " ", 
       RowBox[{"\"\<CurrentPrice\>\"", " ", "->", " ", "S0"}], ",", " ", 
       RowBox[{"\"\<Dividend\>\"", " ", "->", " ", "0"}]}], "}"}], ",", " ", 
     "\"\<ImpliedVolatility\>\""}], "]"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"3", "/", "2"}], " ", "Implied", " ", "Vol"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ImpVol32", "[", 
   RowBox[{
   "S0_", ",", "K_", ",", "T_", ",", "r_", ",", "v0_", ",", "\[Kappa]_", ",", 
    "\[Theta]_", ",", "\[Delta]_", ",", "\[Rho]_"}], "]"}], ":=", 
  RowBox[{"ImpVol", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Call", "[", "32", "]"}], "[", 
     RowBox[{
     "S0", ",", "K", ",", "T", ",", "v0", ",", "\[Kappa]", ",", "\[Theta]", 
      ",", "\[Delta]", ",", "\[Rho]", ",", "r"}], "]"}], ",", " ", "S0", ",", 
    "K", ",", "T", ",", "r"}], "]"}]}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, {3.599756256263191*^9, 3.599756332440287*^9}, {
   3.599756617455538*^9, 3.599756618009652*^9}, {3.599757105893538*^9, 
   3.599757125333712*^9}, 3.599913574518188*^9, 3.5999137015845222`*^9, {
   3.599913735275365*^9, 3.599913735689046*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell["Test:", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599572470029501*^9, 3.599572470582589*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", " ", 
      RowBox[{"Drimus", "[", "2013", "]"}]}]}], " ", "parameters", " ", "for",
     " ", "the", " ", 
    RowBox[{"3", "/", 
     RowBox[{
      RowBox[{"2", " ", "--"}], "--"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Kappa]", "=", "22.84"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Theta]", "=", 
     RowBox[{"0.4669", "^", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Delta]", "=", "8.56"}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Rho]", "=", 
     RowBox[{"-", "0.99"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"v0", "=", 
     SuperscriptBox["0.245", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S0", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"T", "=", 
     RowBox[{"1", "/", "4"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"r", "=", "0.05"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Kmin", "=", 
     RowBox[{"S0", "-", 
      RowBox[{"0.25", " ", 
       SuperscriptBox["T", 
        RowBox[{"1", "/", "2"}]]}]}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Kmax", "=", 
     RowBox[{"S0", "+", 
      RowBox[{"0.25", " ", 
       SuperscriptBox["T", 
        RowBox[{"1", "/", "2"}]]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"IVmin", "=", 
     RowBox[{
      RowBox[{"ImpVol32", "[", 
       RowBox[{
       "S0", ",", "Kmax", ",", "T", ",", "r", ",", "v0", ",", "\[Kappa]", ",",
         "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], "-", "0.01"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"Style", "[", 
     RowBox[{
     "\"\<Implied Vol: Exact (solid) vs our new code 3rd (Red) vs our new \
code 4th (Green)\>\"", ",", "16", ",", "Blue", ",", "Bold"}], "]"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Sigma]bar", "[", "3", "]"}], "[", 
        RowBox[{
        "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
         "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"\[Sigma]bar", "[", "4", "]"}], "[", 
        RowBox[{
        "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
         "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], ",", 
       RowBox[{"ImpVol32", "[", 
        RowBox[{
        "S0", ",", "K", ",", "T", ",", "r", ",", "v0", ",", "\[Kappa]", ",", 
         "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"K", ",", "Kmin", ",", "Kmax"}], "}"}], ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Red", ",", "Dashed"}], "}"}], ",", 
        RowBox[{"{", "Green", "}"}], ",", "Black"}], "}"}]}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Kmin", ",", 
        RowBox[{"IVmin", "-", "0.03"}]}], "}"}]}]}], "]"}]}]}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, 3.5995800475001183`*^9, {3.5995803649031897`*^9, 
   3.599580409592898*^9}, {3.599645075759655*^9, 3.599645161733348*^9}, {
   3.59964690235499*^9, 3.5996469101992292`*^9}, {3.599756699594401*^9, 
   3.5997567947030077`*^9}, 3.599757292784956*^9, {3.59975737703865*^9, 
   3.599757431979044*^9}, {3.5997574654377832`*^9, 3.599757542297001*^9}, {
   3.599757582448118*^9, 3.5997575830149117`*^9}, {3.5997576692936296`*^9, 
   3.599757775188403*^9}, {3.599757806562314*^9, 3.599757811322444*^9}, {
   3.599765298409781*^9, 3.599765349453829*^9}, {3.599802672326753*^9, 
   3.5998027231026573`*^9}, {3.599802964297453*^9, 3.599803077270915*^9}, {
   3.5998031153610935`*^9, 3.5998031325070744`*^9}, {3.599803250194805*^9, 
   3.5998032696329174`*^9}, {3.599913593481798*^9, 3.599913596779451*^9}},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell[BoxData[
 StyleBox["\<\"Implied Vol: Exact (solid) vs our new code 3rd (Red) vs our \
new code 4th (Green)\"\>",
  StripOnInput->False,
  LineColor->RGBColor[0, 0, 1],
  FrontFaceColor->RGBColor[0, 0, 1],
  BackFaceColor->RGBColor[0, 0, 1],
  GraphicsColor->RGBColor[0, 0, 1],
  FontSize->16,
  FontWeight->Bold,
  FontColor->RGBColor[0, 0, 1]]], "Print",
 CellChangeTimes->{
  3.599580055316103*^9, 3.5996450454932623`*^9, {3.5996450759694033`*^9, 
   3.599645161951758*^9}, {3.599646890700325*^9, 3.59964691042918*^9}, 
   3.599756796660585*^9, 3.5997569856164207`*^9, 3.599757138272791*^9, 
   3.599757293770897*^9, 3.5997573817692327`*^9, {3.59975741959864*^9, 
   3.5997574323547373`*^9}, {3.599757466660906*^9, 3.59975754373531*^9}, {
   3.5997577316323757`*^9, 3.599757775549501*^9}, {3.599757806865049*^9, 
   3.599757818063138*^9}, 3.599765699088367*^9, {3.599802645381212*^9, 
   3.599802724060712*^9}, 3.599803078907008*^9, 3.5998031163991528`*^9, 
   3.599803271747038*^9, 3.599803310852275*^9, 3.5999136079791307`*^9, 
   3.5999136592876797`*^9, 3.5999137396814823`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0Hs4lQcABvAS4jy2WjfXcqnwaDPGhlrepSMrl9LKTsgqt0Jx1NKFnmOd
ZLqgGOmUUmpWS9NSMss9vnM4l89RyBDWTn3H+T7XSKd9/fE+7/P75/3jtd4V
vzlSZ8aMGf5sPrSZexVbFJ5168oXPiOhELxtvcJ6jxePk/mUREazx8U1MylY
yvO4BqyngstdjutQ6E7sqpxSkuhIKY3Q16OQTB+430OSyK+72mjEobDFdLit
REpi4ca0DNMFFAT2lg2eT0jMjdo4z8WeworwczGx5SQiTvxd++Q7Cvw93Kbp
bHZ/duLiw8kUNNB7NTuBxMlEH8uw6xQKm04HSAJI8Fsna65LKSxKUNnIHEhc
PkN/bPCGQrNrztoNhiTsPeunJUvVaBFOtukPKvBre0V2Q4AaQlv3jpQaBWIV
I7LOg2qYa4tyoq8ocOox54/AIjXO2mqP5iUrMDQnatUgoQZvSzfXPUQBn2/7
424Pq7E0NE2ZuVIBLX81lIuHkDUv39nZWIEJbVel2bohGDdxVRiXIyDl+44a
/hCK5s+JuKiQ42L/6CWRaAiG/IiGO6VyOPzebpRTP4SCC279KzLlMN6da6HW
DCE0MSlhMlaOdWn57btMNHDam97j6CsHmXvIeSVXgxv2U2UP7OQIOnPExTte
A8uBvDfjunKY/1fdE5engYm//HDBgAyergOfjtdqUNexXz+3RoZr/b7LRK81
uFMcTDNXZBBUxfQ9MqRRRz3NnJkqQ/fMJak8SxqcTWP1sWEydCWN/Ch0odFn
9bDZ1VOG9Ci3VTvX0xAaufiGmMvgtN6o7WkYjbgcZ+PYYSkOb59V+zyRxubb
q0eUZVLwX+0WnEunYZPgRevsk4JTQp9vF9EQV3CzXnwmxeUQw6N/3qURPXBz
tY2mFX1pWV+sbaRRIhRNOtxqRUO/B3Z00rDOfOPXE9sKXkWghSNNY8Pw5PZd
dq04XX0qIEOXge+G6/5nXragsjJoi8CEwS/L9wUuLGnBhc+zHOwcGaSfOsok
RrbARPl6a6gXAyt/t2i+bQvWjdwP9OIxKInmWvi+kCBe7xPr2r0MMnwvKY8X
SuCx/qy3LJXBkc5wj6CdEpTpHVmZmcdAf5OymbNEAsnISeHzWwyWFS7ftrVH
jD6lbVHdYwbKB9m5E1fFKHZyzQpRMpDKgst++kEMTlU4mapisK037oXIWowb
9+ZKulgL9ulWp1uJsea3qvovXzG4NF9WeMBSjEN5xuUq1nczZkX5LRbjJV+c
H0gxOCjsNJo2EaPe1iXMWsNAErW2PmSuGMeydFTVowwCO9s7LN4TMDtZ2mc2
xuCb4sF3BloC91NCOw+wVjTaLRubJkDFlIvtxxl0jHkntUwRCPGOuZM1weB0
sMrt2DgB9yn5/h1TDMwmGm161QTa6GNxj1g/5hnESCgCCS9XRC54y/5zN/ne
w9cEbradCGpibeqg9ctWEVhU6uHh9I5Bpii8wGuQQFnxv84ZrB/ofT3iOEDA
X3TeYYD1NVefAPN+AsKf1eb5WgaR4jHOaC8BK0HBgmHWy+0uxPX2EPjroM9H
fu8ZhDvFyyT/EODtHdW7wdq0L+mrim4CI+FXte9Zu7rcu1z8nMD/mX+OQw==

     "]]}, 
   {RGBColor[0, 1, 0], LineBox[CompressedData["
1:eJwV0Xs0VAkABvBS1Fhb2lRStpRaRypFh2HzlUIlrEhOHpViO+gxsog4o7zS
iy2HMtsioVI2GXk0Sx6luubJtN6kh6k7M/fSUmqmvfvHd77z++f75zMLObYr
VGfKlCkeTP5vE3sBUySuXHfZc/KxDFLuF2EBY9rK3VfTKEPmM3b+5qkkunmm
3smMJ/dW25zRIWHxj9WOsw0ydCVWHNLTJbH7wSyHqwIZ8poLnxjokzB1rphT
WyvDPK+0zIVGJOxJecmn+zIYhnn9YGNBotTsfX5skQyHUv9ueupDImOFT0M3
l9mfEWV68hSJQI1ewqkDMqRHuS0JLiZRXDnh3uwsA0f4+XGxiETR8KXyBDMZ
rl+gZs38RGLfz8aRCToyWDi1fCWWK/HoYl3K+KAUZfLa7FZPJQyUAbdXNEoR
IR0Td8coUdr7LqmwUIpzDfr3vYuUMHeX15VypVDNDnN881yJIJbfbs0BKdy2
DUeWjyqxi3WfY7BVCi1nIzpNVYgN2XaGv1yKCW1PvYmrCq01hOM9XSk8E/d0
Peao0OxYaufxRoL84Y9/8HgqlDn051S2SmB5V25wpUWFoZnl1qFlEiw4nLNY
qVahvsMxSpQhgWtanjzEWI2BtPy7qRESyHLi1jlsVaPzofH6qTsl8LsQb+Ny
TA2rms1eO1ZLsGikcSAyV41lbX1OXYYSONm+thpvUsN2y/Olm0bFuDHsbs77
oMaiHXG3FJ1icAXhQ3UsClRuD3dvnRh9U39M9l9CoW3Pggk+T4ye2LHfUmwo
yM6mzndPFiMjzM7xwHYK8cUxfV0HxbDebtDxMphCedKmVAc3MU4GTWvqjaJg
Hqj79ZmVGJz3h7m/Z1CYWMjShBmKoX+LuiznUXg9LoreS4pwPYCVUPUXhRkB
F+Kja0UYSstav+UJhf4o1mfxaRFah9nY301hjpdebNgvIvjXei9eQ1GY+3LU
J9hEhPON5zwzp9OIuRZZnzwiRH29ny/XmEa/34jR2hohrq7NsvxpDY3V+jH+
v6YIYdz5YXegM43o09kz7vkK4TrG93b2p3Fe53J6gZkQx3TnmDUdoRESNu3V
Gqod7O0XXcTJNG5qfN/eaWpHpW68w6VcGpb8hf3a7HYQY+kpvXdonAnXbrAO
bcdQ58qi5gYaG/sHB3vZ7bhpbZsV0ElDzyflRcZ37dAXHJQlK2jsEyhK6EEC
JQ8MiR7GGnv6lS3jzbcFLRve03AKCloVN0AgLndBtYLxSP+hIW0fgXecF3ne
JI15iexXBj0EWlbaBJupaTRmO9mt6iSQlKWjaPxI48aGAWvOMwIm6RVDJv/S
8OszmuS3EeAnBnZHM275ViOafEqADK9+YTFOg6/wKEh5QiDAJfxe1gSN6Q2V
8rxmAvaTkhP7J2kUXbmT1ywg0EElRdYx7lGSFizGx9+tCjX6QqPqXGGr5yMC
pR2pfm2MyZZQ8+46AvMr2GxrDY38mJBY+iGByptv12UyPurkGmHH2IN32fI1
4/Vlf0YkVhNIOatclKel4XKxKpvFJ7CUe81olPFowfGHXlUEHsW4fb/zG/Pn
6RuKnAcE/I981C1hrD7lYdFbSWDsYKH2G+O5vUdPLGP8H7YPlBM=
     "]]}, 
   {GrayLevel[0], LineBox[CompressedData["
1:eJwV0ns0VAkABnC0s5isVF47SqtNK3WKRkmd5kuKOhsdlhJlFdMpsS0VmTZL
hdKq2SLCdkilMpEe2sgzvdwx5knM9LBqrXFn5l5GbSr27h/f+c7vv++Pz2XH
3hC+mYmJSSCT/5uzrIEpEpqcBp7UUQl5+kdJKeNI0YvXqxjnPPMp9jUloZab
Z9U4KDEWUcs9akbihY2g54y9Ej2Hq2O/ZJHwT1ddCrNVovBh2WMrNomQyu0d
6ilK2G3MyvnaloTgp2K+9kslbHZunMZ1I5G6pz3MYVSB2MzG1ic/kMjI07B/
lSgwZp40M/UXEm6nqhQPriuQnRQwK+oSiTmLHFd2ZyuQKPnQcqmThG3mlvvz
dyhwIZeytviXxIMt0rYVUMCN1/ZJ/K0ORz9ONI3aK3C16/7vj4J0uHI7xeml
UY498hFpb7IOIlHtPbVcjpNN7Jrgizpsyu07YFElh37KzhVv23Wo4zlXkCfl
CFjXHy8a1qE5O2RxZZwc44kroZqph3HOPFG7vxzvx9X1HH897J6mCE67yhF0
eHNPS6IeR3xxr9xUjuJ+4x8lJXrobgfnlr+Uwf1Gl1Vemx4tfrEaz0YZHHbl
z9AZ9BDtDrTkFsvgn1XYtcPRAFWMlaBOIIMi/6Dn8jUGpE493ta8WcbsFHDX
7jXAa1tlUdkSGZz+aX4VX2BA67pSx892MvC83ix412qAkWfP7x+Rorz/+zkl
QwawOPmreUop0hvi+uosKXAvzp4ScleKF6bOGeGzKDhrIqxd86RQp4wcOMal
kBD9pPfGASmO7/ResX09BcumifHpoVJ4rLdSdkdREDUnTBZxpUjdNqlVk0SB
/0r4rsxOikTtrvQzxykURBVxMrWdYF+jznaVUCgzu3Y0uaoTFyItD925SUEa
Gr5qeF8n+rKEi/0eU3DXdQt7vDrxqN8H0b0ULHqM6ogxCcLvB89YSFEIHSpl
R9RL8FvzyaCcL2gcucaKHkiXoL5+U2i6I40fPVy7RwMkOL9I6P7dQhpXFVpe
IVsCR9VQ2NbVNIQFJuW3ZB3wH7kbvDqcRoVfZGlKXgf2sqa6tCbQkG3ft6Y+
vAM+60+tlWbQyLepKYp16cAtlmD56QIaz+wWpLa/FUM8kn1MU0nD6USsLrNK
jD7V3IsPm2g0TR+sqzkoxmUPL2GkisZNVeCzap4Y7IYYRcYgjamreHydhZj5
oY1YzTj+dpTbuLkYvtcb2pZoaajPnRu2ZnywwKF2kPGd/RtKPFhiDCQShcEk
jYFhyZr9pmK0zeVGuRhoqLxnaz99IJAmNBtsNtKYu7s4c/oQAU52dR9nlAby
cue7agncPby1dz/jioj850sHCZBxtYTbOxreaW8DIgYIRK6NqxK+p3H+SNah
sn4Cy8Zk+6LHaIRlNy711BBQUmnxdYwtkycF+akJ/Dwwn2/7kcaNadviw3oJ
VCgzNz1lzOcENaY+J2Bf7ePj8ZlGVYvrvVYlgVuX//bMYXwnzdpcpSAQWHLW
/Q3jmKTJUQNyAsdO6JwKx2k8afF1sZIR+Ca9yHaYceiEINdZSuBBcsBXGyZo
/On91MSzk0B4gpF1hfFfkfMO+UkIjMSUjU8wfr31wqewDgL/AXvTicY=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{0.875, 0.17720385225658},
  Method->{},
  PlotRange->{{0.875, 1.125}, {0.17720385225658, 0.31401449324600406`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.5995800576063957`*^9, 3.599645048380536*^9, {3.599645079006963*^9, 
   3.599645164734126*^9}, {3.59964689357216*^9, 3.599646913279623*^9}, 
   3.599756837007209*^9, 3.599757024126533*^9, 3.599757199475484*^9, 
   3.599757350741817*^9, 3.599757381956621*^9, {3.599757424703352*^9, 
   3.5997574376096983`*^9}, {3.599757479177741*^9, 3.599757556645509*^9}, {
   3.5997577368641*^9, 3.599757824993045*^9}, 3.599765705463591*^9, {
   3.59980265304465*^9, 3.599802731399132*^9}, {3.599803103978442*^9, 
   3.5998031273237777`*^9}, 3.599803271940049*^9, 3.599803336213725*^9, 
   3.599913608756447*^9, 3.599913659831403*^9, 3.5999137606799603`*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Explicit expressions of the implied vol. expansion:\
\>", "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.},
 CellChangeTimes->{{3.5979581326845427`*^9, 3.597958135776731*^9}, {
   3.597958203856258*^9, 3.5979582050665703`*^9}, {3.59796199720356*^9, 
   3.597961998920319*^9}, 3.5986968863608503`*^9, {3.598697015693664*^9, 
   3.598697021494788*^9}, {3.599571613259164*^9, 3.599571615867638*^9}, {
   3.5995717394421453`*^9, 3.599571780029361*^9}, {3.599571861095284*^9, 
   3.5995719616486473`*^9}, {3.599572470029501*^9, 3.599572470582589*^9}, {
   3.599579629345312*^9, 3.599579757268725*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{
  "T", ",", "S0", ",", "v0", ",", "r", ",", "\[Kappa]", ",", "\[Theta]", ",", 
   "\[Delta]", ",", "\[Rho]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]bar", "[", "0", "]"}], "[", 
  RowBox[{
  "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
   "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]bar", "[", "1", "]"}], "[", 
   RowBox[{
   "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
    "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Sigma]bar", "[", "2", "]"}], "[", 
   RowBox[{
   "T", ",", "S0", ",", "K", ",", "v0", ",", "r", ",", "\[Kappa]", ",", 
    "\[Theta]", ",", "\[Delta]", ",", "\[Rho]"}], "]"}], "//", 
  "Simplify"}]}], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 CellChangeTimes->{
  3.598691989455195*^9, 3.5986953620426273`*^9, 3.598696655124875*^9, 
   3.598697015693552*^9, 3.598697925492749*^9, 3.598697956680724*^9, {
   3.5989827728839207`*^9, 3.598982773996007*^9}, {3.598984141054937*^9, 
   3.5989842117381153`*^9}, {3.598984328430603*^9, 3.598984386492887*^9}, {
   3.598984468909821*^9, 3.598984489403379*^9}, 3.5989849038673477`*^9, {
   3.598990603317453*^9, 3.598990691776987*^9}, {3.598990774367199*^9, 
   3.598990777125066*^9}, {3.598991850196443*^9, 3.5989918532609177`*^9}, {
   3.598992009458397*^9, 3.5989920121607428`*^9}, 3.5989946387948437`*^9, {
   3.598994729262558*^9, 3.5989947299578247`*^9}, {3.5989947639328613`*^9, 
   3.598994766068514*^9}, {3.5989969208210487`*^9, 3.59899700563675*^9}, {
   3.599000832945959*^9, 3.599000833132866*^9}, 3.599000942805632*^9, {
   3.5990010289942513`*^9, 3.599001029449898*^9}, {3.599001067888317*^9, 
   3.599001070921986*^9}, 3.599045042774048*^9, 3.599066318247109*^9, 
   3.5995673999433937`*^9, {3.599567547905315*^9, 3.599567579780888*^9}, {
   3.599571987897265*^9, 3.599571988977839*^9}, {3.599572613434569*^9, 
   3.5995726428661613`*^9}, 3.5995745710481853`*^9, {3.599579897320693*^9, 
   3.5995799014539013`*^9}, 3.5995800475001183`*^9, 3.599580084720087*^9, {
   3.5997568371615868`*^9, 3.599756868387689*^9}, {3.599756937591446*^9, 
   3.599756980071669*^9}, 3.5997571639569263`*^9, 3.599757529404544*^9},
 Background->RGBColor[0.870267795834287, 1., 0.9897611963073167]],

Cell[BoxData[
 SqrtBox["v0"]], "Output",
 CellChangeTimes->{{3.59957772402394*^9, 3.5995777284103117`*^9}, 
   3.5995799245957747`*^9, {3.599579955759563*^9, 3.599579974414955*^9}, 
   3.59958001084453*^9, 3.599580086885993*^9, 3.599645168463593*^9, 
   3.5996469232848186`*^9, {3.599756850765764*^9, 3.5997568687682543`*^9}, {
   3.599756931654388*^9, 3.5997569807866793`*^9}, 3.599757199612989*^9, 
   3.599757529677618*^9, 3.599765705616858*^9, 3.5998033363217316`*^9, 
   3.599913634360649*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  SqrtBox["v0"], " ", 
  RowBox[{"(", 
   RowBox[{"8", "-", 
    RowBox[{"T", " ", "v0", " ", 
     SuperscriptBox["\[Delta]", "2"]}], "-", 
    RowBox[{"2", " ", "T", " ", "v0", " ", "\[Kappa]"}], "+", 
    RowBox[{"2", " ", "T", " ", "\[Theta]", " ", "\[Kappa]"}], "-", 
    RowBox[{"2", " ", "r", " ", "T", " ", "\[Delta]", " ", "\[Rho]"}], "+", 
    RowBox[{"T", " ", "v0", " ", "\[Delta]", " ", "\[Rho]"}], "+", 
    RowBox[{"2", " ", "\[Delta]", " ", "\[Rho]", " ", 
     RowBox[{"Log", "[", "K", "]"}]}], "-", 
    RowBox[{"2", " ", "\[Delta]", " ", "\[Rho]", " ", 
     RowBox[{"Log", "[", "S0", "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.59957772402394*^9, 3.5995777284103117`*^9}, 
   3.5995799245957747`*^9, {3.599579955759563*^9, 3.599579974414955*^9}, 
   3.59958001084453*^9, 3.599580086885993*^9, 3.599645168463593*^9, 
   3.5996469232848186`*^9, {3.599756850765764*^9, 3.5997568687682543`*^9}, {
   3.599756931654388*^9, 3.5997569807866793`*^9}, 3.599757199612989*^9, 
   3.599757529677618*^9, 3.599765705616858*^9, 3.5998033363217316`*^9, 
   3.599913634362328*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "384"], " ", 
  SqrtBox["v0"], " ", 
  RowBox[{"(", 
   RowBox[{"384", "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["\[Delta]", "2"]}], "-", 
    RowBox[{"16", " ", "T", " ", "v0", " ", 
     SuperscriptBox["\[Delta]", "2"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["v0", "2"], " ", 
     SuperscriptBox["\[Delta]", "2"]}], "+", 
    RowBox[{"13", " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["v0", "2"], " ", 
     SuperscriptBox["\[Delta]", "4"]}], "-", 
    RowBox[{"96", " ", "T", " ", "v0", " ", "\[Kappa]"}], "+", 
    RowBox[{"52", " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["v0", "2"], " ", 
     SuperscriptBox["\[Delta]", "2"], " ", "\[Kappa]"}], "+", 
    RowBox[{"96", " ", "T", " ", "\[Theta]", " ", "\[Kappa]"}], "-", 
    RowBox[{"36", " ", 
     SuperscriptBox["T", "2"], " ", "v0", " ", 
     SuperscriptBox["\[Delta]", "2"], " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
    RowBox[{"52", " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["v0", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "-", 
    RowBox[{"72", " ", 
     SuperscriptBox["T", "2"], " ", "v0", " ", "\[Theta]", " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "+", 
    RowBox[{"20", " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["\[Theta]", "2"], " ", 
     SuperscriptBox["\[Kappa]", "2"]}], "-", 
    RowBox[{"96", " ", "r", " ", "T", " ", "\[Delta]", " ", "\[Rho]"}], "+", 
    RowBox[{"48", " ", "T", " ", "v0", " ", "\[Delta]", " ", "\[Rho]"}], "+", 
    
    RowBox[{"28", " ", "r", " ", 
     SuperscriptBox["T", "2"], " ", "v0", " ", 
     SuperscriptBox["\[Delta]", "3"], " ", "\[Rho]"}], "-", 
    RowBox[{"26", " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["v0", "2"], " ", 
     SuperscriptBox["\[Delta]", "3"], " ", "\[Rho]"}], "+", 
    RowBox[{"56", " ", "r", " ", 
     SuperscriptBox["T", "2"], " ", "v0", " ", "\[Delta]", " ", "\[Kappa]", 
     " ", "\[Rho]"}], "-", 
    RowBox[{"52", " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["v0", "2"], " ", "\[Delta]", " ", "\[Kappa]", " ", 
     "\[Rho]"}], "-", 
    RowBox[{"24", " ", "r", " ", 
     SuperscriptBox["T", "2"], " ", "\[Delta]", " ", "\[Theta]", " ", 
     "\[Kappa]", " ", "\[Rho]"}], "+", 
    RowBox[{"36", " ", 
     SuperscriptBox["T", "2"], " ", "v0", " ", "\[Delta]", " ", "\[Theta]", 
     " ", "\[Kappa]", " ", "\[Rho]"}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["r", "2"], " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["\[Delta]", "2"], " ", 
     SuperscriptBox["\[Rho]", "2"]}], "-", 
    RowBox[{"28", " ", "T", " ", "v0", " ", 
     SuperscriptBox["\[Delta]", "2"], " ", 
     SuperscriptBox["\[Rho]", "2"]}], "-", 
    RowBox[{"28", " ", "r", " ", 
     SuperscriptBox["T", "2"], " ", "v0", " ", 
     SuperscriptBox["\[Delta]", "2"], " ", 
     SuperscriptBox["\[Rho]", "2"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["T", "2"], " ", 
     SuperscriptBox["v0", "2"], " ", 
     SuperscriptBox["\[Delta]", "2"], " ", 
     SuperscriptBox["\[Rho]", "2"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["\[Delta]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       SuperscriptBox["\[Rho]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"Log", "[", "K", "]"}], "2"]}], "+", 
    RowBox[{"4", " ", "\[Delta]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "r", " ", "T", " ", "\[Delta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          SuperscriptBox["\[Rho]", "2"]}], ")"}]}], "+", 
       RowBox[{"\[Rho]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "24"}], "+", 
          RowBox[{"T", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "6"}], " ", "\[Theta]", " ", "\[Kappa]"}], "+", 
             RowBox[{"7", " ", "v0", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[Delta]", "2"], "+", 
                RowBox[{"2", " ", "\[Kappa]"}], "-", 
                RowBox[{"\[Delta]", " ", "\[Rho]"}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}], " ", 
     RowBox[{"Log", "[", "S0", "]"}]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["\[Delta]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       SuperscriptBox["\[Rho]", "2"]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"Log", "[", "S0", "]"}], "2"]}], "+", 
    RowBox[{"4", " ", "\[Delta]", " ", 
     RowBox[{"Log", "[", "K", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "r", " ", "T", " ", "\[Delta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          SuperscriptBox["\[Rho]", "2"]}], ")"}]}], "+", 
       RowBox[{"\[Rho]", " ", 
        RowBox[{"(", 
         RowBox[{"24", "+", 
          RowBox[{"T", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", " ", "\[Theta]", " ", "\[Kappa]"}], "-", 
             RowBox[{"7", " ", "v0", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["\[Delta]", "2"], "+", 
                RowBox[{"2", " ", "\[Kappa]"}], "-", 
                RowBox[{"\[Delta]", " ", "\[Rho]"}]}], ")"}]}]}], ")"}]}]}], 
         ")"}]}], "+", 
       RowBox[{"4", " ", "\[Delta]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          SuperscriptBox["\[Rho]", "2"]}], ")"}], " ", 
        RowBox[{"Log", "[", "S0", "]"}]}]}], ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.59957772402394*^9, 3.5995777284103117`*^9}, 
   3.5995799245957747`*^9, {3.599579955759563*^9, 3.599579974414955*^9}, 
   3.59958001084453*^9, 3.599580086885993*^9, 3.599645168463593*^9, 
   3.5996469232848186`*^9, {3.599756850765764*^9, 3.5997568687682543`*^9}, {
   3.599756931654388*^9, 3.5997569807866793`*^9}, 3.599757199612989*^9, 
   3.599757529677618*^9, 3.599765705616858*^9, 3.5998033363217316`*^9, 
   3.599913634688216*^9}]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1440, 852},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Microsoft Windows (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1485, 35, 748, 14, 86, "Section",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[CellGroupData[{
Cell[2258, 53, 197, 4, 68, "Section"],
Cell[2458, 59, 1352, 26, 220, "Text"]
}, Open  ]],
Cell[3825, 88, 377, 5, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[4205, 95, 2507, 76, 295, "DisplayFormula"],
Cell[6715, 173, 679, 11, 39, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[7397, 186, 10575, 270, 509, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[17975, 458, 702, 11, 35, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[18680, 471, 9703, 236, 615, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[28386, 709, 522, 7, 35, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[CellGroupData[{
Cell[28933, 720, 5402, 119, 340, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[34338, 841, 1088, 21, 25, "Print"],
Cell[35429, 864, 6168, 109, 272, "Output"]
}, Open  ]]
}, Open  ]],
Cell[41624, 977, 626, 10, 35, "Subsubsection",
 CellGroupingRules->{GroupTogetherGrouping, 10001.}],
Cell[CellGroupData[{
Cell[42275, 991, 2460, 45, 96, "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.}],
Cell[44738, 1038, 498, 8, 33, "Output"],
Cell[45239, 1048, 1147, 22, 48, "Output"],
Cell[46389, 1072, 6260, 157, 114, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Rv05EFRStR57KDKomjIIRcHy *)
